@@ -31,7 +31,9 @@ extern Colormap xe_cm;
 
 extern FILE *fopenh P_((char *name, char *how));
 extern Obj *db_scan P_((DBScan *sp));
-extern char *getBaseDir P_((void));
+extern char *expand_home P_((char *path));
+extern char *getShareDir P_((void));
+extern char *getXRes P_((char *name, char *def));
 extern char *syserrstr P_((void));
 extern int confirm P_((void));
 extern int db_n P_((void));
@@ -57,6 +59,7 @@ extern void xe_msg P_((char *msg, int app_modal));
 
 static void db_create_form P_((void));
 static void initFSB P_((Widget fsb_w));
+static void initPubShared P_((Widget rb_w, Widget fsb_w));
 static void db_set_report P_((void));
 static FILE *fileopen P_((char *name));
 static void db_append_cb P_((Widget w, XtPointer client, XtPointer data));
@@ -148,7 +151,7 @@ db_create_form ()
 	    {"Notes...", "Database - notes"},
 	};
 	Widget mb_w, pd_w, cb_w;
-	Widget fsb_w, sep_w;
+	Widget sep_w, fsb_w, rc_w;
 	XmString str;
 	Widget w;
 	Arg args[20];
@@ -337,16 +340,28 @@ db_create_form ()
 	sep_w = XmCreateSeparator (dbform_w, "Sep", args, n);
 	XtManageChild (sep_w);
 
-	/* make the file selection box */
+	/* make the Share/User rapid dir choices */
 
 	n = 0;
 	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	XtSetArg (args[n], XmNtopWidget, sep_w); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNorientation, XmHORIZONTAL); n++;
+	XtSetArg (args[n], XmNspacing, 5); n++;
+	rc_w = XmCreateRowColumn (dbform_w, "DRB", args, n);
+	XtManageChild (rc_w);
+
+	/* make the file selection box */
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	XtSetArg (args[n], XmNtopWidget, rc_w); n++;
 	XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
 	XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
 	XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
 	fsb_w = XmCreateFileSelectionBox (dbform_w, "FSB", args, n);
 	initFSB (fsb_w);	/* do this before managing for Ultrix :-) */
+	initPubShared (rc_w, fsb_w);
 	wtip (fsb_w, "Select a file to read and add objects to memory");
 	XtManageChild (fsb_w);
 
@@ -376,11 +391,69 @@ Widget fsb_w;
 {
 	char buf[1024];
 
-	(void) sprintf (buf, "%s/catalogs",  getBaseDir());
-	set_xmstring (fsb_w, XmNdirectory, buf);
+	(void) sprintf (buf, "%s/catalogs",  getShareDir());
+	set_xmstring (fsb_w, XmNdirectory, expand_home(buf));
 	set_xmstring (fsb_w, XmNpattern, "*.edb");
 }
 
+/* callback from the Public dir PB */
+/* ARGSUSED */
+static void
+sharedDirCB (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	Widget fsb_w = (Widget)client;
+	char buf[1024];
+
+	(void) sprintf (buf, "%s/catalogs", getShareDir());
+	set_xmstring (fsb_w, XmNdirectory, expand_home(buf));
+}
+
+/* callback from the Private dir PB */
+/* ARGSUSED */
+static void
+privateDirCB (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	Widget fsb_w = (Widget)client;
+
+	set_xmstring (fsb_w, XmNdirectory,
+				    expand_home(getXRes("PrivateDir", "work")));
+}
+
+/* build a set of PB in RC rc_w so that they
+ * set the XmNdirectory resource in the FSB fsb_w and invoke the Filter.
+ */
+static void
+initPubShared (rc_w, fsb_w)
+Widget rc_w, fsb_w;
+{
+	Arg args[20];
+	Widget w;
+	int n;
+
+	n = 0;
+	w = XmCreateLabel (rc_w, "Dir", args, n);
+	set_xmstring (w, XmNlabelString, "Go to:");
+	XtManageChild (w);
+
+	n = 0;
+	w = XmCreatePushButton (rc_w, "Private", args, n);
+	XtAddCallback(w, XmNactivateCallback, privateDirCB, (XtPointer)fsb_w);
+	wtip (w,"Set Filter directory to value of XEphem.PrivateDir resource");
+	XtManageChild (w);
+
+	n = 0;
+	w = XmCreatePushButton (rc_w, "Shared", args, n);
+	XtAddCallback(w, XmNactivateCallback, sharedDirCB, (XtPointer)fsb_w);
+	wtip (w,"Set Filter directory to XEphem.ShareDir/catalogs");
+	XtManageChild (w);
+}
+
 /* compile the stats report into report_w.
  * N.B. we do not include the planets nor the user objects.
  */
@@ -618,3 +691,6 @@ XtPointer data;
 {
 	XtUnmanageChild (dbform_w);
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: dbmenu.c,v $ $Date: 1999/03/03 19:06:34 $ $Revision: 1.2 $ $Name:  $"};
