@@ -4,349 +4,435 @@
 char Version_resource[50];
 
 String fallbacks[] = {
-    "XEphem.JD: Now",
-    "XEphem.Sitename: Chicago, Illinois",
-    "XEphem.DeltaT: Auto on",
-    "XEphem.Temp: 10",
-    "XEphem.Pressure: 1010",
-    "XEphem.Epoch: 2000",
-    "XEphem.TwilightDip: 18",
-    "XEphem.NSteps: 1",
-    "XEphem.Pause: 0",
-    "XEphem.StepSize: RT Clock",
-    "XEphem*XmText.fontList: -*-lucidatypewriter-medium-r-*-*-12-*-*-*-m-*-*-*",
-    "XEphem*XmTextField.fontList: -*-lucidatypewriter-medium-r-*-*-12-*-*-*-m-*-*-*",
-    "XEphem*XmList.fontList: -*-lucidatypewriter-medium-r-*-*-12-*-*-*-m-*-*-*",
-    "XEphem*XmLabel.fontList: -*-lucida-medium-r-*-*-12-*-*-*-p-*-*-*",
-    "XEphem*fontList: -*-lucida-medium-r-*-*-12-*-*-*-p-*-*-*",
-    "XEphem.viewsFont: -*-helvetica-medium-r-*-*-14-*-*-*-*-*-*-*",
-    "XEphem.viewsGreekFont: -*-symbol-*-*-*-*-14-*-*-*-*-*-*-*",
-    "XEphem.trailsFont: -*-helvetica-medium-r-*-*-14-*-*-*-*-*-*-*",
-    "XEphem.CnsFont: -*-times-medium-i-*-*-14-*-*-*-*-*-*-*",
-    "XEphem.install: guess",
-    "XEphem.tipForeground: #11f",
-    "XEphem.tipBackground: white",
-    "XEphem*background: #feb",
-    "XEphem*foreground: #500",
-    "XEphem*XmCascadeButton.foreground: #f00",
-    "XEphem*XmPushButton.foreground: #03f",
-    "XEphem*XmToggleButton.foreground: #03f",
-    "XEphem*XmText.foreground: #11f",
-    "XEphem*XmScale.foreground: #a80",
-    "XEphem*MainPrompt*background: #fd6",
-    "XEphem*ObjPrompt*background: #fd6",
-    "XEphem*Print*background: #fd6",
-    "XEphem*Query*background: #fd6",
-    "XEphem*NetStop*background: #fd6",
-    "XEphem*SaveAs*background: #fd6",
-    "XEphem*SkyList*background: #fd6",
-    "XEphem*ModalMessage*background: #fd6",
-    "XEphem*Equatorial.Topocentric.set: False",
-    "XEphem*Precision.Hi.set: True",
-    "XEphem*MessageBell.Off.set: False",
-    "XEphem*PromptPreFill.No.set: False",
-    "XEphem*Units.English.set: False",
-    "XEphem*TZone.Local.set: False",
-    "XEphem*Tips.No.set: False",
-    "XEphem*Confirm.No.set: False",
-    "XEphem*DateFormat.MDY.set: True",
-    "XEphem*DateFormat.YMD.set: False",
-    "XEphem*DateFormat.DMY.set: False",
-    "XEphem.UserDir: ~/XEphem",
-    "XEphem.BaseDir: .",
-    "XEphem*FieldStars*GSCCDDirectory.value: /mnt/cdrom",
-    "XEphem.FITSpattern:  *.f*ts",
-    "XEphem*SkyFITS*Header.rows: 8",
-    "XEphem*SkyFITS*Header.columns: 40",
-    "XEphem*SkyFITS*AutoName.set: True",
-    "XEphem*SkyFITS*GrayMethod.HEq.set: False",
-    "XEphem*SkyFITS*GrayMethod.Gamma.set: True",
-    "XEphem*SkyFITS*Histogram.height: 50",
-    "XEphem*SkyFITS*Inverse.set: False",
-    "XEphem*SkyFITS*GammaScale.value: 50",
-    "XEphem*SkyFITS.x: 600",
-    "XEphem*SkyFITS.y: 10",
-    "XEphem*SkyFITS*Histogram.foreground: red",
-    "XEphem*SkyFITS*Histogram.background: #333",
-    "XEphem.FITSHistoColor: yellow",
-    "XEphem.FITSMapColor: orange",
-    "XEphem*FieldStars*GSCCD.set: False",
-    "XEphem*FieldStars*GSCCache.set: True",
-    "XEphem*FieldStars*XEphemdbdNet.set: False",
-    "XEphem*FieldStars*XEphemdbdURL.value: /iro.physics.uiowa.edu/cgi-bin/xephemdbd/xephemdbd.pl",
-    "XEphem*FieldStars*ESONet.set: False",
-    "XEphem*FieldStars*PPM.set: True",
-    "XEphem*FieldStars*NoDups.set: True",
-    "XEphem*FieldStars*SAOHD.set: True",
-    "XEphem*FieldStars*Proxy.set: False",
-    "XEphem*FieldStars*ProxyHost.value: a.b.com",
-    "XEphem*FieldStars*ProxyPort.value: 8000",
-    "XEphem*FieldStars*SOCKS.set: False",
-    "XEphem*FieldStars*SOCKSHost.value: x.y.com",
-    "XEphem*FieldStars*SOCKSPort.value: 1080",
-    "XEphem.DBinitialFiles: Messier.edb NGC.edb SAC.edb YBS.edb asteroids.edb comets.edb mir.edb",
-    "XEphem*Print*Save.set: True",
-    "XEphem*Print*Grayscale.set: True",
-    "XEphem*Print*PrintCmd.value: lpr",
+    "XEphem*AboutMap.background: #222",
+    "XEphem*AboutMap.foreground: #fff",
     "XEphem*AdpDispl.value: 0",
+    "XEphem*CloseObjs*AutoUp.set: False",
+    "XEphem*CloseObjs*List.doubleClickInterval: 500",
+    "XEphem*CloseObjs*List.visibleItemCount: 10",
+    "XEphem*CloseObjs*Mag.value: 20.0",
+    "XEphem*CloseObjs*OmitFixedPairs.set: True",
+    "XEphem*CloseObjs*Sep.value: 2.0",
+    "XEphem*Confirm.No.set: False",
+    "XEphem*DBManage*NoDups.set: True",
     "XEphem*Data.x: 100",
     "XEphem*Data.y: 200",
+    "XEphem*DataSelMiscCols.Air.set: False",
+    "XEphem*DataSelMiscCols.Alt.set: True",
+    "XEphem*DataSelMiscCols.Az.set: True",
+    "XEphem*DataSelMiscCols.Cns.set: False",
+    "XEphem*DataSelMiscCols.Dec.set: True",
+    "XEphem*DataSelMiscCols.EaDst.set: False",
+    "XEphem*DataSelMiscCols.Elong.set: False",
+    "XEphem*DataSelMiscCols.HA.set: False",
+    "XEphem*DataSelMiscCols.HeLat.set: False",
+    "XEphem*DataSelMiscCols.HeLong.set: False",
+    "XEphem*DataSelMiscCols.Phase.set: False",
+    "XEphem*DataSelMiscCols.RA.set: True",
+    "XEphem*DataSelMiscCols.Size.set: False",
+    "XEphem*DataSelMiscCols.SnDst.set: False",
+    "XEphem*DataSelMiscCols.VMag.set: False",
     "XEphem*DataSelRisetCols*Limb.set: True",
-    "XEphem*DataSelRows.Sun.set: True",
-    "XEphem*DataSelRows.Moon.set: True",
-    "XEphem*DataSelRows.Mercury.set: False",
-    "XEphem*DataSelRows.Venus.set: False",
-    "XEphem*DataSelRows.Mars.set: False",
+    "XEphem*DataSelRisetCols.HrsUp.set: False",
+    "XEphem*DataSelRisetCols.RiseAz.set: False",
+    "XEphem*DataSelRisetCols.RiseTm.set: True",
+    "XEphem*DataSelRisetCols.SetAz.set: False",
+    "XEphem*DataSelRisetCols.SetTm.set: True",
+    "XEphem*DataSelRisetCols.TrnAlt.set: False",
+    "XEphem*DataSelRisetCols.TrnTm.set: False",
     "XEphem*DataSelRows.Jupiter.set: False",
-    "XEphem*DataSelRows.Saturn.set: False",
-    "XEphem*DataSelRows.Uranus.set: False",
+    "XEphem*DataSelRows.Mars.set: False",
+    "XEphem*DataSelRows.Mercury.set: False",
+    "XEphem*DataSelRows.Moon.set: True",
     "XEphem*DataSelRows.Neptune.set: False",
     "XEphem*DataSelRows.Pluto.set: False",
-    "XEphem*DataSelMiscCols.Cns.set: False",
-    "XEphem*DataSelMiscCols.RA.set: True",
-    "XEphem*DataSelMiscCols.HA.set: False",
-    "XEphem*DataSelMiscCols.Dec.set: True",
-    "XEphem*DataSelMiscCols.Az.set: True",
-    "XEphem*DataSelMiscCols.Alt.set: True",
-    "XEphem*DataSelMiscCols.Air.set: False",
-    "XEphem*DataSelMiscCols.HeLong.set: False",
-    "XEphem*DataSelMiscCols.HeLat.set: False",
-    "XEphem*DataSelMiscCols.EaDst.set: False",
-    "XEphem*DataSelMiscCols.SnDst.set: False",
-    "XEphem*DataSelMiscCols.Elong.set: False",
-    "XEphem*DataSelMiscCols.Size.set: False",
-    "XEphem*DataSelMiscCols.VMag.set: False",
-    "XEphem*DataSelMiscCols.Phase.set: False",
-    "XEphem*DataSelRisetCols.RiseTm.set: True",
-    "XEphem*DataSelRisetCols.RiseAz.set: False",
-    "XEphem*DataSelRisetCols.TrnTm.set: False",
-    "XEphem*DataSelRisetCols.TrnAlt.set: False",
-    "XEphem*DataSelRisetCols.SetTm.set: True",
-    "XEphem*DataSelRisetCols.SetAz.set: False",
-    "XEphem*DataSelRisetCols.HrsUp.set: False",
-    "XEphem*DataSelSepCols.Sun.set: False",
-    "XEphem*DataSelSepCols.Moon.set: False",
-    "XEphem*DataSelSepCols.Mercury.set: False",
-    "XEphem*DataSelSepCols.Venus.set: False",
-    "XEphem*DataSelSepCols.Mars.set: False",
+    "XEphem*DataSelRows.Saturn.set: False",
+    "XEphem*DataSelRows.Sun.set: True",
+    "XEphem*DataSelRows.Uranus.set: False",
+    "XEphem*DataSelRows.Venus.set: False",
     "XEphem*DataSelSepCols.Jupiter.set: False",
-    "XEphem*DataSelSepCols.Saturn.set: False",
-    "XEphem*DataSelSepCols.Uranus.set: False",
+    "XEphem*DataSelSepCols.Mars.set: False",
+    "XEphem*DataSelSepCols.Mercury.set: False",
+    "XEphem*DataSelSepCols.Moon.set: False",
     "XEphem*DataSelSepCols.Neptune.set: False",
     "XEphem*DataSelSepCols.Pluto.set: False",
+    "XEphem*DataSelSepCols.Saturn.set: False",
+    "XEphem*DataSelSepCols.Sun.set: False",
+    "XEphem*DataSelSepCols.Uranus.set: False",
+    "XEphem*DataSelSepCols.Venus.set: False",
+    "XEphem*DateFormat.DMY.set: False",
+    "XEphem*DateFormat.MDY.set: True",
+    "XEphem*DateFormat.YMD.set: False",
+    "XEphem*Earth*Map.background: #222",
+    "XEphem*Earth*Map.foreground: #fff",
+    "XEphem*Earth*Map.height: 300",
+    "XEphem*Earth*Map.width: 600",
+    "XEphem*Earth*cylindrical.set: True",
+    "XEphem*Earth*grid.set: True",
+    "XEphem*Earth*lowprec.set: False",
+    "XEphem*Earth*object.set: True",
+    "XEphem*Earth*sites.set: True",
+    "XEphem*Earth*spherical.set: False",
+    "XEphem*Earth*sunlight.set: True",
+    "XEphem*Earth*track.set: False",
+    "XEphem*Earth*trail.set: True",
+    "XEphem*Earth.x: 100",
+    "XEphem*Earth.y: 300",
+    "XEphem*Equatorial.Topocentric.set: False",
+    "XEphem*FieldStars*ESONet.set: False",
+    "XEphem*FieldStars*GSCCDDirectory: /mnt/cdrom",
+    "XEphem*FieldStars*GSCCD.set: False",
+    "XEphem*FieldStars*GSCCache.set: False",
+    "XEphem*FieldStars*NoDups.set: True",
+    "XEphem*FieldStars*USNO.set: False",
+    "XEphem*FieldStars*PPM.set: False",
+    "XEphem*FieldStars*SAOHD.set: True",
+    "XEphem*FieldStars*Tycho.set: False",
+    "XEphem*FieldStars*XEphemdbdNet.set: False",
+    "XEphem*FieldStars*XEphemdbdURL.value: /denali.physics.uiowa.edu/cgi-bin/xephemdbd/xephemdbd.pl",
+    "XEphem*Help*HelpText.columns: 80",
+    "XEphem*Help*HelpText.rows: 24",
+    "XEphem*Help.verticalSpacing: 20",
     "XEphem*Jupiter*BrightMoons.set: False",
-    "XEphem*Jupiter*SkyBkg.set: False",
-    "XEphem*Jupiter*Tags.set: True",
-    "XEphem*Jupiter*FlipTB.set: False",
     "XEphem*Jupiter*FlipLR.set: False",
-    "XEphem*Jupiter*Scale.value: 50",
+    "XEphem*Jupiter*FlipTB.set: False",
     "XEphem*Jupiter*LimMag.value: 10",
-    "XEphem*Jupiter*Map.height: 200",
-    "XEphem*Jupiter*Map.width: 300",
-    "XEphem*Jupiter.x: 100",
-    "XEphem*Jupiter.y: 200",
-    "XEphem*JupiterStats*GRSSysIILong.value: 61",
     "XEphem*Jupiter*Map.background: #222",
     "XEphem*Jupiter*Map.foreground: #fda",
-    "XEphem.JupiterGRSColor: #f88",
-    "XEphem*Saturn*BrightMoons.set: False",
-    "XEphem*Saturn*SkyBkg.set: False",
-    "XEphem*Saturn*Tags.set: True",
-    "XEphem*Saturn*FlipTB.set: False",
-    "XEphem*Saturn*FlipLR.set: False",
-    "XEphem*Saturn*Scale.value: 50",
-    "XEphem*Saturn*LimMag.value: 10",
-    "XEphem*Saturn*Map.height: 200",
-    "XEphem*Saturn*Map.width: 400",
-    "XEphem*Saturn.x: 400",
-    "XEphem*Saturn.y: 200",
-    "XEphem*Saturn*Map.background: #222",
-    "XEphem*Saturn*Map.foreground: #fe7",
-    "XEphem*Moon.x: 50",
-    "XEphem*Moon.y: 10",
-    "XEphem*Moon.width: 700",
-    "XEphem*Moon.height: 700",
-    "XEphem*MoonES*Earthshine.value: 4",
+    "XEphem*Jupiter*Map.height: 300",
+    "XEphem*Jupiter*Map.width: 300",
+    "XEphem*Jupiter*Scale.value: 50",
+    "XEphem*Jupiter*SkyBkg.set: False",
+    "XEphem*Jupiter*Tags.set: True",
+    "XEphem*Jupiter.x: 200",
+    "XEphem*Jupiter.y: 400",
+    "XEphem*JupiterStats*GRSSysIILong.value: 61",
+    "XEphem*JupiterTV*Map.height: 300",
+    "XEphem*List.x: 500",
+    "XEphem*List.y: 200",
+    "XEphem*ListRC.spacing: 5",
+    "XEphem*MainPrompt*background: #fd6",
+    "XEphem*Mars*FlipLR.set: False",
+    "XEphem*Mars*FlipTB.set: False",
+    "XEphem*Mars*Grid.set: False",
+    "XEphem*Mars*Labels.set: False",
+    "XEphem*Mars*LowPrec.set: False",
+    "XEphem*Mars*Map.background: #222",
+    "XEphem*Mars*Map.foreground: #fa5",
+    "XEphem*Mars*SkyBkg.set: False",
+    "XEphem*Mars.height: 600",
+    "XEphem*Mars.width: 500",
+    "XEphem*Mars.x: 100",
+    "XEphem*Mars.y: 50",
+    "XEphem*MarsMoons*BrightMoons.set: False",
+    "XEphem*MarsMoons*FlipLR.set: False",
+    "XEphem*MarsMoons*FlipTB.set: False",
+    "XEphem*MarsMoons*LimMag.value: 17",
+    "XEphem*MarsMoons*Map.background: #222",
+    "XEphem*MarsMoons*Map.foreground: #fa5",
+    "XEphem*MarsMoons*Map.height: 300",
+    "XEphem*MarsMoons*Map.width: 300",
+    "XEphem*MarsMoons*Scale.value: 80",
+    "XEphem*MarsMoons*SkyBkg.set: False",
+    "XEphem*MarsMoons*Tags.set: True",
+    "XEphem*MarsMoons.x: 450",
+    "XEphem*MarsMoons.y: 400",
+    "XEphem*MarsMoonsTV*Map.height: 300",
+    "XEphem*MarsStats*Seeing.maximum: 5",
+    "XEphem*MarsStats*Seeing.minimum: 0",
+    "XEphem*MarsStats*Seeing.value: 0",
+    "XEphem*Message*Messages.columns: 80",
+    "XEphem*Message*Messages.rows: 10",
+    "XEphem*Message.verticalSpacing: 20",
+    "XEphem*MessageBell.Off.set: False",
+    "XEphem*ModalMessage*background: #fd6",
     "XEphem*Moon*Apollo.set: True",
-    "XEphem*Moon*Labels.set: False",
-    "XEphem*Moon*SkyBkg.set: False",
-    "XEphem*Moon*Image.set: True",
-    "XEphem*Moon*Umbra.set: True",
-    "XEphem*Moon*FlipTB.set: False",
     "XEphem*Moon*FlipLR.set: False",
+    "XEphem*Moon*FlipTB.set: False",
     "XEphem*Moon*Grid.set: False",
+    "XEphem*Moon*Image.set: True",
+    "XEphem*Moon*Labels.set: False",
+    "XEphem*Moon*MoonDA.background: #222",
+    "XEphem*Moon*MoonDA.foreground: #fff",
     "XEphem*Moon*Scale1X.set: False",
     "XEphem*Moon*Scale2X.set: False",
     "XEphem*Moon*Scale3X.set: True",
     "XEphem*Moon*Scale6X.set: False",
-    "XEphem.GlassBorderColor: yellow",
-    "XEphem*Moon*MoonDA.foreground: #fff",
-    "XEphem*Moon*MoonDA.background: #222",
-    "XEphem.MoonAnnotColor: #f33",
-    "XEphem*Mars.x: 100",
-    "XEphem*Mars.y: 50",
-    "XEphem*Mars.width: 500",
-    "XEphem*Mars.height: 600",
-    "XEphem*Mars*Labels.set: False",
-    "XEphem*Mars*SkyBkg.set: False",
-    "XEphem*Mars*FlipTB.set: False",
-    "XEphem*Mars*FlipLR.set: False",
-    "XEphem*Mars*Grid.set: False",
-    "XEphem*Mars*LowPrec.set: False",
-    "XEphem*MarsStats*Seeing.minimum: 0",
-    "XEphem*MarsStats*Seeing.maximum: 5",
-    "XEphem*MarsStats*Seeing.value: 0",
-    "XEphem*Mars*Map.foreground: #fa5",
-    "XEphem*Mars*Map.background: #222",
-    "XEphem.MarsAnnotColor: white",
-    "XEphem*Earth*cylindrical.set: True",
-    "XEphem*Earth*spherical.set: False",
-    "XEphem*Earth*track.set: False",
-    "XEphem*Earth*trail.set: True",
-    "XEphem*Earth*grid.set: True",
-    "XEphem*Earth*object.set: True",
-    "XEphem*Earth*sites.set: True",
-    "XEphem*Earth*sunlight.set: True",
-    "XEphem*Earth*lowprec.set: False",
-    "XEphem*Earth.x: 100",
-    "XEphem*Earth.y: 300",
-    "XEphem*Earth*Map.height: 300",
-    "XEphem*Earth*Map.width: 600",
-    "XEphem*Earth*Map.foreground: #fff",
-    "XEphem*Earth*Map.background: #222",
-    "XEphem.EarthGridColor: #383",
-    "XEphem.EarthSiteColor: #f09",
-    "XEphem.EarthObjColor: #f00",
-    "XEphem.EarthEclipseColor: #333",
-    "XEphem.EarthSunColor: #bb0",
-    "XEphem.EarthBorderColor: #77a",
-    "XEphem.EarthHereColor: #fff",
-    "XEphem*Progress*DA.width:200",
-    "XEphem*Progress*DA.height:25",
+    "XEphem*Moon*SkyBkg.set: False",
+    "XEphem*Moon*Umbra.set: True",
+    "XEphem*Moon.height: 700",
+    "XEphem*Moon.width: 700",
+    "XEphem*Moon.x: 50",
+    "XEphem*Moon.y: 10",
+    "XEphem*MoonES*Earthshine.value: 4",
+    "XEphem*NetSetup*Direct.set: True",
+    "XEphem*NetSetup*Proxy.set: False",
+    "XEphem*NetSetup*ProxyHost.value: a.b.com",
+    "XEphem*NetSetup*ProxyPort.value: 8000",
+    "XEphem*NetSetup*SOCKS.set: False",
+    "XEphem*NetSetup*SOCKSHost.value: x.y.com",
+    "XEphem*NetSetup*SOCKSPort.value: 1080",
+    "XEphem*NetStop*background: #fd6",
+    "XEphem*ObjPrompt*background: #fd6",
+    "XEphem*Plot.x: 100",
+    "XEphem*Plot.y: 200",
+    "XEphem*PlotDA.background: #444",
+    "XEphem*PlotDA.foreground: #3f3",
+    "XEphem*PlotDA.height: 400",
+    "XEphem*PlotDA.width: 400",
+    "XEphem*PlotDisplay*FlipX.set: False",
+    "XEphem*PlotDisplay*FlipY.set: False",
+    "XEphem*PlotDisplay*Grid.set: True",
+    "XEphem*PlotDisplay*XAsDate.set: False",
+    "XEphem*PlotRC.spacing: 5",
+    "XEphem*Precision.Hi.set: True",
+    "XEphem*Print*Grayscale.set: True",
+    "XEphem*Print*PrintCmd.value: lpr",
+    "XEphem*Print*Save.set: True",
+    "XEphem*Print*background: #fd6",
     "XEphem*Progress*DA.foreground:green",
-    "XEphem*SolarSystem.x: 100",
-    "XEphem*SolarSystem.y: 100",
-    "XEphem*SolarSystem*Trails.set: True",
+    "XEphem*Progress*DA.height:25",
+    "XEphem*Progress*DA.width:200",
+    "XEphem*PromptPreFill.No.set: False",
+    "XEphem*Query*background: #fd6",
+    "XEphem*Saturn*BrightMoons.set: False",
+    "XEphem*Saturn*FlipLR.set: False",
+    "XEphem*Saturn*FlipTB.set: False",
+    "XEphem*Saturn*LimMag.value: 15",
+    "XEphem*Saturn*Map.background: #222",
+    "XEphem*Saturn*Map.foreground: #fe7",
+    "XEphem*Saturn*Map.height: 300",
+    "XEphem*Saturn*Map.width: 400",
+    "XEphem*Saturn*Scale.value: 50",
+    "XEphem*Saturn*SkyBkg.set: False",
+    "XEphem*Saturn*Tags.set: True",
+    "XEphem*Saturn.x: 400",
+    "XEphem*Saturn.y: 400",
+    "XEphem*SaturnTV*Map.height: 300",
+    "XEphem*SaveAs*background: #fd6",
+    "XEphem*SiteSL.visibleItemCount: 10",
+    "XEphem*SkyEyep*Elliptical.set: True",
+    "XEphem*SkyEyep*EyepH.maximum: 300",
+    "XEphem*SkyEyep*EyepH.minimum: 1",
+    "XEphem*SkyEyep*EyepH.value: 50",
+    "XEphem*SkyEyep*EyepW.maximum: 300",
+    "XEphem*SkyEyep*EyepW.minimum: 1",
+    "XEphem*SkyEyep*EyepW.value: 50",
+    "XEphem*SkyEyep*Lock.set: True",
+    "XEphem*SkyEyep*Outline.set: False",
+    "XEphem*SkyEyep*Rectangular.set: False",
+    "XEphem*SkyEyep*Solid.set: True",
+    "XEphem*SkyFITS*AutoName.set: True",
+    "XEphem*SkyFITS*GammaScale.value: 50",
+    "XEphem*SkyFITS*GrayMethod.Gamma.set: True",
+    "XEphem*SkyFITS*GrayMethod.HEq.set: False",
+    "XEphem*SkyFITS*Header.columns: 40",
+    "XEphem*SkyFITS*Header.rows: 8",
+    "XEphem*SkyFITS*Histogram.background: #333",
+    "XEphem*SkyFITS*Histogram.foreground: red",
+    "XEphem*SkyFITS*Histogram.height: 50",
+    "XEphem*SkyFITS*Inverse.set: False",
+    "XEphem*SkyFITS*UseGzip.set: True",
+    "XEphem*SkyFITS.x: 600",
+    "XEphem*SkyFITS.y: 10",
+    "XEphem*SkyFilter*AutoMag.set: True",
+    "XEphem*SkyFilter*Binary.set: True",
+    "XEphem*SkyFilter*BrightNeb.set: True",
+    "XEphem*SkyFilter*ClInNeb.set: True",
+    "XEphem*SkyFilter*DarkNeb.set: True",
+    "XEphem*SkyFilter*DeepSkyMag.value: 7",
+    "XEphem*SkyFilter*DiffuseNeb.set: True",
+    "XEphem*SkyFilter*Double.set: True",
+    "XEphem*SkyFilter*EarthSat.set: True",
+    "XEphem*SkyFilter*Elliptical.set: True",
+    "XEphem*SkyFilter*GalClusters.set: True",
+    "XEphem*SkyFilter*GlobularCl.set: True",
+    "XEphem*SkyFilter*Hyperbolic.set: True",
+    "XEphem*SkyFilter*MagStep.value: 1",
+    "XEphem*SkyFilter*Multiple.set: True",
+    "XEphem*SkyFilter*NearSkyMag.value: 5",
+    "XEphem*SkyFilter*OpenCl.set: True",
+    "XEphem*SkyFilter*Parabolic.set: True",
+    "XEphem*SkyFilter*PlanetaryNeb.set: True",
+    "XEphem*SkyFilter*Planets.set: True",
+    "XEphem*SkyFilter*Pulsars.set: True",
+    "XEphem*SkyFilter*Quasars.set: True",
+    "XEphem*SkyFilter*Radio.set: True",
+    "XEphem*SkyFilter*SNRemnants.set: True",
+    "XEphem*SkyFilter*SphericalGal.set: True",
+    "XEphem*SkyFilter*SpiralGal.set: True",
+    "XEphem*SkyFilter*Stars.set: True",
+    "XEphem*SkyFilter*Stellar.set: True",
+    "XEphem*SkyFilter*SymbolDA.background: #222",
+    "XEphem*SkyFilter*SymbolDA.foreground: #fff",
+    "XEphem*SkyFilter*SymbolDA.width: 25",
+    "XEphem*SkyFilter*Undefined.set: True",
+    "XEphem*SkyFilter*Variable.set: True",
+    "XEphem*SkyFilter.x: 400",
+    "XEphem*SkyFilter.y: 10",
+    "XEphem*SkyList*background: #fd6",
+    "XEphem*SkyOps*AltAzMode.set: True",
+    "XEphem*SkyOps*CnsBoundaries.set: False",
+    "XEphem*SkyOps*CnsFigures.set: True",
+    "XEphem*SkyOps*CnsNames.set: False",
+    "XEphem*SkyOps*Ecliptic.set: False",
+    "XEphem*SkyOps*Eyepieces.set: True",
+    "XEphem*SkyOps*FieldStars.set: True",
+    "XEphem*SkyOps*FlipLR.set: False",
+    "XEphem*SkyOps*FlipTB.set: False",
+    "XEphem*SkyOps*Galactic.set: False",
+    "XEphem*SkyOps*Grid*AltAz.set: True",
+    "XEphem*SkyOps*Grid*Auto.set: True",
+    "XEphem*SkyOps*Grid*Full.set: True",
+    "XEphem*SkyOps*Grid*Grid.set: False",
+    "XEphem*SkyOps*HznMap.set: False",
+    "XEphem*SkyOps*JustDots.set: True",
+    "XEphem*SkyOps*LblAll.set: False",
+    "XEphem*SkyOps*LblBrightDeep.set: False",
+    "XEphem*SkyOps*LblBrightNear.set: True",
+    "XEphem*SkyOps*LblFldStars.set: True",
+    "XEphem*SkyOps*LblMags.set: False",
+    "XEphem*SkyOps*LblNames.set: True",
+    "XEphem*SkyOps*LiveDrag.set: True",
+    "XEphem*SkyOps*LiveReport.set: False",
+    "XEphem*SkyOps*MagScale.set: True",
+    "XEphem*SkyOps.x: 500",
+    "XEphem*SkyOps.y: 10",
+    "XEphem*SkyView*AltDecScale.scaleMultiple: 1",
+    "XEphem*SkyView*AltDecScale.value: 1080",
+    "XEphem*SkyView*AzRAScale.scaleMultiple: 1",
+    "XEphem*SkyView*AzRAScale.value: 2160",
+    "XEphem*SkyView*FOVScale.scaleMultiple: 1",
+    "XEphem*SkyView*FOVScale.value: 2160",
+    "XEphem*SkyView*InFIFO.set: False",
+    "XEphem*SkyView*LocFIFO.set: False",
+    "XEphem*SkyView*Map.background: #222",
+    "XEphem*SkyView*Map.foreground: #7f7",
+    "XEphem*SkyView*Map.height: 600",
+    "XEphem*SkyView*Map.width: 600",
+    "XEphem*SkyView.x: 200",
+    "XEphem*SkyView.y: 10",
+    "XEphem*SkyZoom.x: 50",
+    "XEphem*SkyZoom.y: 10",
     "XEphem*SolarSystem*AllObjs.set: False",
     "XEphem*SolarSystem*AllObjsLegs.set: False",
     "XEphem*SolarSystem*Ecliptic.set: True",
     "XEphem*SolarSystem*Labels.set: True",
     "XEphem*SolarSystem*Legs.set: True",
-    "XEphem*SolarSystem*LiveDragging.set: True",
-    "XEphem*SolarSystem.HLongScale.value: 0",
-    "XEphem*SolarSystem.DistScale.value: 50",
-    "XEphem*SolarSystem.HLatScale.value: 90",
-    "XEphem*SolarSystem*SolarDA.height: 500",
-    "XEphem*SolarSystem*SolarDA.width: 500",
+    "XEphem*SolarSystem*LiveDrag.set: True",
     "XEphem*SolarSystem*SolarDA.background: #222",
     "XEphem*SolarSystem*SolarDA.foreground: #5b5",
+    "XEphem*SolarSystem*SolarDA.height: 500",
+    "XEphem*SolarSystem*SolarDA.width: 500",
+    "XEphem*SolarSystem*Trails.set: True",
+    "XEphem*SolarSystem.DistScale.value: 50",
+    "XEphem*SolarSystem.HLatScale.value: 90",
+    "XEphem*SolarSystem.HLongScale.value: 0",
+    "XEphem*SolarSystem.x: 100",
+    "XEphem*SolarSystem.y: 100",
+    "XEphem*Srch*SrchFunction.rows: 5",
+    "XEphem*Srch.x: 200",
+    "XEphem*Srch.y: 300",
+    "XEphem*SrchRC.spacing: 5",
     "XEphem*StereoSolarSystem*StereoDA.background: #222",
     "XEphem*StereoSolarSystem*StereoDA.foreground: #fff",
-    "XEphem*SkyView*AzRAScale.value: 2160",
-    "XEphem*SkyView*AltDecScale.value: 1080",
-    "XEphem*SkyView*FOVScale.value: 2160",
-    "XEphem*SkyView*FOVScale.scaleMultiple: 1",
-    "XEphem*SkyView*AltDecScale.scaleMultiple: 1",
-    "XEphem*SkyView*AzRAScale.scaleMultiple: 1",
-    "XEphem*SkyView.x: 200",
-    "XEphem*SkyView.y: 10",
-    "XEphem*SkyView*Map.width: 600",
-    "XEphem*SkyView*Map.height: 600",
-    "XEphem*SkyView*InFIFO.set: False",
-    "XEphem*SkyView*LocFIFO.set: False",
-    "XEphem.SkyEyePColor: #b33",
-    "XEphem*SkyView*Map.background: #222",
-    "XEphem*SkyView*Map.foreground: #7f7",
-    "XEphem.SkyCnsFigColor: #bb3",
-    "XEphem.SkyCnsBndColor: #b77",
-    "XEphem.SkyCnsNamColor: #ff0",
-    "XEphem.SkyGridColor: #595",
-    "XEphem.SkyEqColor: #f30",
-    "XEphem*SkyOps*AltAzMode.set: True",
-    "XEphem*SkyOps*JustDots.set: True",
-    "XEphem*SkyOps*FlipLR.set: False",
-    "XEphem*SkyOps*FlipTB.set: False",
-    "XEphem*SkyOps*Ecliptic.set: False",
-    "XEphem*SkyOps*Grid*Grid.set: False",
-    "XEphem*SkyOps*Grid*Auto.set: True",
-    "XEphem*SkyOps*Grid*AltAz.set: True",
-    "XEphem*SkyOps*Grid*Full.set: True",
-    "XEphem*SkyOps*Galactic.set: False",
-    "XEphem*SkyOps*Eyepieces.set: True",
-    "XEphem*SkyOps*MagScale.set: True",
-    "XEphem*SkyOps*FieldStars.set: True",
-    "XEphem*SkyOps*RoamRpt.set: False",
-    "XEphem*SkyOps*CnsBoundaries.set: False",
-    "XEphem*SkyOps*CnsFigures.set: True",
-    "XEphem*SkyOps*CnsNames.set: False",
-    "XEphem*SkyOps*LblNames.set: True",
-    "XEphem*SkyOps*LblMags.set: False",
-    "XEphem*SkyOps*LblAll.set: False",
-    "XEphem*SkyOps*LblBrightDeep.set: False",
-    "XEphem*SkyOps*LblBrightNear.set: True",
-    "XEphem*SkyOps*LblFldStars.set: True",
-    "XEphem*SkyOps.x: 500",
-    "XEphem*SkyOps.y: 10",
-    "XEphem.SkyNBright: 20",
-    "XEphem*SkyFilter*DeepSkyMag.value: 7",
-    "XEphem*SkyFilter*NearSkyMag.value: 5",
-    "XEphem*SkyFilter*MagStep.value: 1",
-    "XEphem*SkyFilter*SymbolDA.foreground: #fff",
-    "XEphem*SkyFilter*SymbolDA.background: #222",
-    "XEphem*SkyFilter*SymbolDA.width: 25",
-    "XEphem*SkyFilter.x: 400",
-    "XEphem*SkyFilter.y: 10",
-    "XEphem*SkyFilter*Planets.set: True",
-    "XEphem*SkyFilter*Elliptical.set: True",
-    "XEphem*SkyFilter*Hyperbolic.set: True",
-    "XEphem*SkyFilter*Parabolic.set: True",
-    "XEphem*SkyFilter*EarthSat.set: True",
-    "XEphem*SkyFilter*Pulsars.set: True",
-    "XEphem*SkyFilter*Quasars.set: True",
-    "XEphem*SkyFilter*Radio.set: True",
-    "XEphem*SkyFilter*Stellar.set: True",
-    "XEphem*SkyFilter*SNRemnants.set: True",
-    "XEphem*SkyFilter*Undefined.set: True",
-    "XEphem*SkyFilter*Stars.set: True",
-    "XEphem*SkyFilter*Binary.set: True",
-    "XEphem*SkyFilter*Double.set: True",
-    "XEphem*SkyFilter*Multiple.set: True",
-    "XEphem*SkyFilter*Variable.set: True",
-    "XEphem*SkyFilter*BrightNeb.set: True",
-    "XEphem*SkyFilter*DiffuseNeb.set: True",
-    "XEphem*SkyFilter*DarkNeb.set: True",
-    "XEphem*SkyFilter*PlanetaryNeb.set: True",
-    "XEphem*SkyFilter*SpiralGal.set: True",
-    "XEphem*SkyFilter*SphericalGal.set: True",
-    "XEphem*SkyFilter*GalClusters.set: True",
-    "XEphem*SkyFilter*GlobularCl.set: True",
-    "XEphem*SkyFilter*OpenCl.set: True",
-    "XEphem*SkyFilter*ClInNeb.set: True",
-    "XEphem*SkyFilter*AutoMag.set: True",
-    "XEphem*SkyEyep*EyepW.minimum: 1",
-    "XEphem*SkyEyep*EyepW.maximum: 300",
-    "XEphem*SkyEyep*EyepW.value: 50",
-    "XEphem*SkyEyep*EyepH.minimum: 1",
-    "XEphem*SkyEyep*EyepH.maximum: 300",
-    "XEphem*SkyEyep*EyepH.value: 50",
-    "XEphem*SkyEyep*Elliptical.set: True",
-    "XEphem*SkyEyep*Rectangular.set: False",
-    "XEphem*SkyEyep*Solid.set: True",
-    "XEphem*SkyEyep*Outline.set: False",
-    "XEphem*SkyEyep*Lock.set: True",
-    "XEphem.AutoMag: .35 18 16 1, .7 17 15 1, .9 16 14 1, 1.4 15 13 1, 2.8 14 12 1, 5.6 13 11 1, 11 12 10 1, 22 11 9 1, 45 10 8 1, 90 9 7 1, 180 7 5 1",
-    "XEphem*Trails*NTicks.maximum: 250",
+    "XEphem*TZone.Local.set: False",
+    "XEphem*Tips.No.set: False",
     "XEphem*Trails*CustomInterval.value: 0:30",
-    "XEphem*PlotDisplay*FlipX.set: False",
-    "XEphem*PlotDisplay*FlipY.set: False",
-    "XEphem*PlotDisplay*Grid.set: True",
-    "XEphem*PlotDisplay*XAsDate.set: False",
-    "XEphem*PlotDA.height: 400",
-    "XEphem*PlotDA.width: 400",
-    "XEphem*Plot.x: 100",
-    "XEphem*Plot.y: 200",
-    "XEphem*PlotDA.foreground: #3f3",
-    "XEphem*PlotDA.background: #444",
+    "XEphem*Trails*NTicks.maximum: 250",
+    "XEphem*Units.English.set: False",
+    "XEphem*Update.accelerator: Ctrl<Key>u",
+    "XEphem*Update.acceleratorText: Ctrl+u",
+    "XEphem*Uranus*BrightMoons.set: False",
+    "XEphem*Uranus*FlipLR.set: False",
+    "XEphem*Uranus*FlipTB.set: False",
+    "XEphem*Uranus*LimMag.value: 17",
+    "XEphem*Uranus*Map.background: #222",
+    "XEphem*Uranus*Map.foreground: #fda",
+    "XEphem*Uranus*Map.height: 300",
+    "XEphem*Uranus*Map.width: 300",
+    "XEphem*Uranus*Scale.value: 50",
+    "XEphem*Uranus*SkyBkg.set: False",
+    "XEphem*Uranus*Tags.set: True",
+    "XEphem*Uranus.x: 300",
+    "XEphem*Uranus.y: 400",
+    "XEphem*UranusTV*Map.height: 300",
+    "XEphem*XephemMain*MainForm.XmFrame.bottomOffset: 1",
+    "XEphem*XephemMain*MainForm.XmFrame.leftOffset: 1",
+    "XEphem*XephemMain*MainForm.XmFrame.marginHeight: 1",
+    "XEphem*XephemMain*MainForm.XmFrame.marginWidth: 1",
+    "XEphem*XephemMain*MainForm.XmFrame.rightOffset: 1",
+    "XEphem*XephemMain*MainForm.XmFrame.topOffset: 1",
+    "XEphem*XmCascadeButton.foreground: #f00",
+    "XEphem*XmFrame.marginHeight: 0",
+    "XEphem*XmFrame.marginWidth: 0",
+    "XEphem*XmLabel.fontList: -*-lucidatypewriter-bold-r-*-*-12-*-*-*-m-*-*-*",
+    "XEphem*XmList.fontList: -*-lucidatypewriter-bold-r-*-*-12-*-*-*-m-*-*-*",
+    "XEphem*XmPushButton.foreground: #03f",
+    "XEphem*XmScale.foreground: #a80",
+    "XEphem*XmText.fontList: -*-lucidatypewriter-bold-r-*-*-12-*-*-*-m-*-*-*",
+    "XEphem*XmText.foreground: #11f",
+    "XEphem*XmTextField.fontList: -*-lucidatypewriter-bold-r-*-*-12-*-*-*-m-*-*-*",
+    "XEphem*XmToggleButton.foreground: #03f",
+    "XEphem*background: #feb",
+    "XEphem*blinkRate: 0",
+    "XEphem*fontList: -*-lucidatypewriter-bold-r-*-*-12-*-*-*-m-*-*-*",
+    "XEphem*foreground: #500",
+    "XEphem*highlightThickness: 0",
+    "XEphem*marginHeight: 1",
+    "XEphem*marginWidth: 1",
+    "XEphem*marginLeft: 1",
+    "XEphem*marginRight: 1",
+    "XEphem*spacing: 1",
+    "XEphem.AutoMag: .35 18 16 1, .7 17 15 1, .9 16 14 1, 1.4 15 13 1, 2.8 14 12 1, 5.6 13 11 1, 11 12 10 1, 22 11 9 1, 45 10 8 1, 90 9 7 1, 180 7 5 1",
+    "XEphem.CalOtherMonthColor: gray50",
+    "XEphem.CnsFont: -*-times-medium-i-*-*-14-*-*-*-*-*-*-*",
+    "XEphem.DBinitialFiles: Messier.edb NGC.edb SAC.edb YBS.edb minorpl.edb comets.edb ISS.edb",
+    "XEphem.DeltaT: Turn Auto on",
+    "XEphem.EarthBorderColor: #77a",
+    "XEphem.EarthEclipseColor: #333",
+    "XEphem.EarthGridColor: #383",
+    "XEphem.EarthHereColor: #fff",
+    "XEphem.EarthObjColor: #f00",
+    "XEphem.EarthSiteColor: #f09",
+    "XEphem.EarthSunColor: #fe0",
+    "XEphem.Epoch: 2000",
+    "XEphem.FITSHistoColor: yellow",
+    "XEphem.FITSMapColor: orange",
+    "XEphem.FITSpattern:  *.f*ts",
+    "XEphem.GlassBorderColor: yellow",
+    "XEphem.JD: Now",
+    "XEphem.JupiterGRSColor: #f88",
+    "XEphem.MarsAnnotColor: #8f8",
+    "XEphem.MoonAnnotColor: #f44",
+    "XEphem.NSteps: 1",
+    "XEphem.Pause: 0",
+    "XEphem.Pressure: 1010",
+    "XEphem.PrivateDir: ~/XEphem",
+    "XEphem.ShareDir: .",
+    "XEphem.Sitename: Chicago, Illinois",
+    "XEphem.SkyCnsBndColor: #b77",
+    "XEphem.SkyCnsFigColor: #bb3",
+    "XEphem.SkyCnsNamColor: #ff0",
+    "XEphem.SkyEqColor: #f30",
+    "XEphem.SkyEyePColor: #b33",
+    "XEphem.SkyGridColor: #595",
+    "XEphem.SkyNBright: 20",
+    "XEphem.SkyTrackFont: -*-lucidatypewriter-medium-r-*-*-12-*-*-*-m-*-*-*",
+    "XEphem.StepSize: RT Clock",
+    "XEphem.Temp: 10",
+    "XEphem.TwilightDip: 18",
+    "XEphem.allowShellResize: True",
+    "XEphem.coolStarColor: #f75",
+    "XEphem.hotStarColor: #bef",
+    "XEphem.install: guess",
+    "XEphem.jupiterColor: Cyan",
+    "XEphem.marsColor: #f80",
+    "XEphem.mediumStarColor: #ffc",
+    "XEphem.mercuryColor: Red",
+    "XEphem.moonColor: Grey",
+    "XEphem.neptuneColor: #0bf",
+    "XEphem.otherStellarColor: #2f5",
     "XEphem.plotColor0: white",
     "XEphem.plotColor1: #4f4",
     "XEphem.plotColor2: orange",
@@ -357,62 +443,20 @@ String fallbacks[] = {
     "XEphem.plotColor7: wheat",
     "XEphem.plotColor8: gray",
     "XEphem.plotColor9: pink",
-    "XEphem.mercuryColor: Red",
-    "XEphem.venusColor: Green",
-    "XEphem.marsColor: #f80",
-    "XEphem.jupiterColor: Cyan",
-    "XEphem.saturnColor: #eea",
-    "XEphem.uranusColor: #0f9",
-    "XEphem.neptuneColor: #0bf",
     "XEphem.plutoColor: Orange",
-    "XEphem.sunColor: Yellow",
-    "XEphem.moonColor: Grey",
-    "XEphem.hotStarColor: #bef",
-    "XEphem.mediumStarColor: #ffc",
-    "XEphem.coolStarColor: #f75",
-    "XEphem.otherStellarColor: #2f5",
+    "XEphem.saturnColor: #eea",
     "XEphem.solSysColor: #cfc",
-    "XEphem*Help*HelpText.rows: 24",
-    "XEphem*Help*HelpText.columns: 80",
-    "XEphem*Help.verticalSpacing: 20",
-    "XEphem*Message*Messages.rows: 10",
-    "XEphem*Message*Messages.columns: 80",
-    "XEphem*Message.verticalSpacing: 20",
-    "XEphem*CloseObjs*AutoUp.set: False",
-    "XEphem*CloseObjs*Mag.value: 20.0",
-    "XEphem*CloseObjs*Sep.value: 2.0",
-    "XEphem*CloseObjs*OmitFixedPairs.set: True",
-    "XEphem*CloseObjs*List.visibleItemCount: 10",
-    "XEphem*CloseObjs*List.doubleClickInterval: 500",
-    "XEphem*DBManage*NoDups.set: True",
-    "XEphem*List.x: 500",
-    "XEphem*List.y: 200",
-    "XEphem*Srch.x: 200",
-    "XEphem*Srch.y: 300",
-    "XEphem*Srch*SrchFunction.rows: 5",
-    "XEphem*AboutMap.foreground: #fff",
-    "XEphem*AboutMap.background: #222",
-    "XEphem*highlightThickness: 0",
-    "XEphem*XephemMain*MainForm.XmFrame.marginHeight: 1",
-    "XEphem*XephemMain*MainForm.XmFrame.marginWidth: 1",
-    "XEphem*XephemMain*MainForm.XmFrame.topOffset: 1",
-    "XEphem*XephemMain*MainForm.XmFrame.bottomOffset: 1",
-    "XEphem*XephemMain*MainForm.XmFrame.leftOffset: 1",
-    "XEphem*XephemMain*MainForm.XmFrame.rightOffset: 1",
-    "XEphem*Update.accelerator: Ctrl<Key>u",
-    "XEphem*Update.acceleratorText: Ctrl+u",
-    "XEphem*SiteSL.visibleItemCount: 10",
-    "XEphem*SrchRC.spacing: 5",
-    "XEphem*PlotRC.spacing: 5",
-    "XEphem*ListRC.spacing: 5",
-    "XEphem.allowShellResize: True",
-    "XEphem*marginWidth: 1",
-    "XEphem*marginHeight: 1",
-    "XEphem*XmFrame.marginWidth: 0",
-    "XEphem*XmFrame.marginHeight: 0",
-    "XEphem*spacing: 1",
-    "XEphem*blinkRate: 0",
+    "XEphem.sunColor: Yellow",
+    "XEphem.tipBackground: white",
+    "XEphem.tipForeground: #11f",
+    "XEphem.trailsFont: -*-helvetica-medium-r-*-*-14-*-*-*-*-*-*-*",
+    "XEphem.uranusColor: #0f9",
+    "XEphem.venusColor: Green",
+    "XEphem.viewsFont: -*-helvetica-medium-r-*-*-14-*-*-*-*-*-*-*",
+    "XEphem.viewsGreekFont: -*-symbol-*-*-*-*-14-*-*-*-*-*-*-*",
     "XEphem.xephem_main*resizePolicy: RESIZE_ANY",
     Version_resource,
     NULL
 };
+
+/* $Id: fallbacks.c,v 1.20 1999/03/16 16:39:07 ecdowney Exp $ */
