@@ -31,6 +31,7 @@ extern void *malloc(), *realloc();
 #include "circum.h"
 
 extern char *syserrstr P_((void));
+extern int existsh P_((char *path));
 extern FILE *fopenh P_((char *name, char *how));
 extern void pm_set P_((int percent));
 extern void zero_mem P_((void *loc, unsigned len));
@@ -114,7 +115,6 @@ static int inFOV P_((Request *qp, GSCEntry *ep));
 static int magOK P_((Request *qp, GSCEntry *ep));
 static int addOneStar P_((GSCArray *ap, GSCRegion *rp, GSCEntry *ep));
 static int mymkdir P_((char *path));
-static int myaccess P_((char *file));
 
 static void gscPickRegion P_((double ra, double dec, GSCRegion *rp));
 static int gscOpenRegion P_((GSCRegion *rp));
@@ -173,6 +173,7 @@ char msg[];
 		if (!r.fp)
 		    return (-1);
 	    }
+	    gscCloseRegion (&r);
 	}
 
 #ifndef VMS
@@ -186,7 +187,7 @@ char msg[];
 	    
 	    (void) strcpy (r.dir, "");
 	    cacheBuildDir (fullpath, &r);
-	    if (myaccess (fullpath) < 0) {
+	    if (existsh (fullpath) < 0) {
 		(void) sprintf (msg, "%s: %s", chp, syserrstr());
 		return (-1);
 	    }
@@ -494,19 +495,6 @@ char *path;
 	return (mkdir (path, 0755));
 }
 
-/* return 0 if we can open the file, else -1 */
-static int
-myaccess (file)
-char *file;
-{
-	FILE *fp = fopen (file, "r");
-
-	if (!fp)
-	    return (-1);
-	fclose (fp);
-	return (0);
-}
-
 
 /* code to handle the details of reading the CDROM */
 
@@ -1236,3 +1224,6 @@ GSCEntry *ep;
 	buf[1] = RS(i,0);
 	fwrite (buf, 1, 2, fp);
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: gsc.c,v $ $Date: 1999/03/03 19:06:34 $ $Revision: 1.3 $ $Name:  $"};
