@@ -32,9 +32,11 @@ extern Widget	toplevel_w;
 #define	XtD	XtDisplay(toplevel_w)
 extern Colormap xe_cm;
 
+extern FILE *fopenh P_((char *name, char *how));
 extern Now *mm_get_now P_((void));
 extern Obj *db_basic P_((int id));
 extern Obj *db_scan P_((DBScan *sp));
+extern char *getShareDir P_((void));
 extern double atod P_((char *buf));
 extern double delra P_((double dra));
 extern int any_ison P_((void));
@@ -43,6 +45,8 @@ extern int fs_fetch P_((Now *np, double ra, double dec, double fov,
 extern int get_color_resource P_((Widget w, char *cname, Pixel *p));
 extern int magdiam P_((int fmag, int magstp, double scale, double mag,
     double size));
+extern int read_bdl P_((FILE *fp, double jd, double *xp, double *yp,
+    double *zp, char ynot[]));
 extern int skyloc_fifo P_((Obj *op));
 extern void db_scaninit P_((DBScan *sp, int mask, ObjF *op, int nop));
 extern void db_update P_((Obj *op));
@@ -72,8 +76,8 @@ extern void xe_msg P_((char *buf, int app_modal));
 /* These values are from the Explanatory Supplement.
  * Precession degrades them gradually over time.
  */
-#define	POLE_RA		degrad(268.04)	/* RA of Jupiter's north pole */
-#define	POLE_DEC	degrad(64.49)	/* Dec of Jupiter's north pole */
+#define	POLE_RA		degrad(268.05)	/* RA of Jupiter's north pole */
+#define	POLE_DEC	degrad(64.50)	/* Dec of Jupiter's north pole */
 
 /* local record of what is now on screen for easy id from mouse picking.
  */
@@ -85,8 +89,15 @@ typedef struct {
     int x, y;		/* screen coord */
 } ScreenObj;
 
+/* malloced arrays for each view */
+typedef enum {
+    SO_MAIN, SO_TOP, SO_N
+} SOIdx;
+static ScreenObj *screenobj[SO_N];
+static int nscreenobj[SO_N];
 
 static void jm_create_form_w P_((void));
+static void jm_create_tvform_w P_((void));
 static void jm_create_jsform_w P_((void));
 static void jm_set_buttons P_((int whether));
 static void jm_set_a_button P_((Widget pbw, int whether));
@@ -94,6 +105,10 @@ static void jm_sstats_cb P_((Widget w, XtPointer client, XtPointer call));
 static void jm_option_cb P_((Widget w, XtPointer client, XtPointer call));
 static void jm_scale_cb P_((Widget w, XtPointer client, XtPointer call));
 static void jm_activate_cb P_((Widget w, XtPointer client, XtPointer call));
+static void jt_unmap_cb P_((Widget w, XtPointer client, XtPointer call));
+static void jt_map_cb P_((Widget w, XtPointer client, XtPointer call));
+static void jt_track_size P_((void));
+static void jt_da_exp_cb P_((Widget w, XtPointer client, XtPointer call));
 static void jm_unmap_cb P_((Widget w, XtPointer client, XtPointer call));
 static void jm_close_cb P_((Widget w, XtPointer client, XtPointer call));
 static void jm_movie_cb P_((Widget w, XtPointer client, XtPointer call));
@@ -107,28 +122,33 @@ static void jm_locfifo_cb P_((Widget w, XtPointer client, XtPointer call));
 static void jm_grsl_cb P_((Widget w, XtPointer client, XtPointer call));
 static void j_calibline P_((Display *dsp, Drawable win, GC gc, int xc, int yc,
     char *tag, int tw, int th, int l));
-static void jgrs_draw P_((Drawable dr, int rad, int jx, int jy, int fliptb,
-    int fliplr, double grsl, double cmlII));
+static void jgrs_draw P_((Obj *jop, Drawable dr, int rad, int jx, int jy, int
+    fliptb, int fliplr, double grsl, double cmlII));
 
-static void add_screenobj P_((Obj *op, int x, int y));
-static void reset_screenobj P_((void));
-static ScreenObj *close_screenobj P_((int x, int y));
+static void add_screenobj P_((SOIdx, Obj *op, int x, int y));
+static void reset_screenobj P_((SOIdx));
+static ScreenObj *close_screenobj P_((SOIdx, int x, int y));
 
 static void sky_background P_((Drawable win, unsigned w, unsigned h, int fmag,
-    double ra0, double dec0, double salpha, double calpha, double scale, double
-    rad, int fliptb, int fliplr));
+    double ra0, double dec0, double scale, double rad, int fliptb, int fliplr));
 
 static Widget jupform_w;	/* main form */
 static Widget jsform_w;		/* statistics form */
-static Widget jda_w;		/* drawing area */
+static Widget jmframe_w;	/* main frame */
+static Widget jtform_w;		/* top-view form */
+static Widget jtframe_w;	/* top-view frame */
+static Widget jda_w;		/* main drawing area */
+static Widget jtda_w;		/* top-view drawing area */
 static Widget cmlI_w, cmlII_w;	/* labels for displaying GRS coords */
 static Widget scale_w;		/* size scale */
 static Widget limmag_w;		/* limiting magnitude scale */
 static Widget dt_w;		/* main date/time stamp widget */
 static Widget sdt_w;		/* statistics date/time stamp widget */
 static Widget skybkg_w;		/* toggle for controlling sky background */
+static Widget topview_w;	/* toggle for controlling top view */
 static Widget grsl_w;		/* TF of GRS Sys II longitude, degrees */
 static Pixmap jm_pm;		/* main pixmap */
+static Pixmap jt_pm;		/* top-view pixmap */
 static GC j_fgc, j_bgc, j_xgc;	/* various colors and operators */
 static GC jgrs_gc;      	/* gc to use for spot */
 static XFontStruct *j_fs;	/* font for labels */
@@ -139,6 +159,7 @@ static int tags;		/* whether we want tags on the drawing */
 static int flip_tb;		/* whether we want to flip top/bottom */
 static int flip_lr;		/* whether we want to flip left/right */
 static int skybkg;		/* whether we want sky background */
+static int topview;		/* whether we want the top view */
 static int jswasman;		/* whether statistics form was managed */
 
 static Widget jmpu_w;		/* main popup */
@@ -173,14 +194,9 @@ static struct MoonNames {
     {"Callisto", "IV"}
 };
 
-enum {CX, CY, CZ, CRA, CDEC, CMAG, CNum};	/* j_w column index */
+enum {CEV, CSV, CX, CY, CZ, CRA, CDEC, CMAG, CNum};	/* j_w column index */
 static Widget	j_w[NM][CNum];			/* the data display widgets */
 
-/* malloced array for each item on screen. used for picking. */
-static ScreenObj *screenobj;
-static int nscreenobj;
-
-
 /* called when the jupiter menu is activated via the main menu pulldown.
  * if never called before, create and manage all the widgets as a child of a
  * form. otherwise, just toggle whether the form is managed.
@@ -275,6 +291,8 @@ jm_create_form_w()
 	    char *tip;		/* widget tip */
 	} Option;
 	static Option options[] = {
+	    {"TopView",	   "Top view",		&topview, &topview_w,
+	    	"When on, show view looking from high above N pole"},
 	    {"SkyBkg",	   "Sky background",	&skybkg,  &skybkg_w,
 	    	"When on, sky will include database objects and Field Stars"},
 	    {"BrightMoons","Bright moons",	&brmoons, NULL,
@@ -297,7 +315,6 @@ jm_create_form_w()
 	    {"on View...",	"Jupiter - view"},
 	};
 	Widget w;
-	Widget frame_w;
 	Widget mb_w, pd_w, cb_w;
 	XmString str;
 	Arg args[20];
@@ -524,15 +541,16 @@ jm_create_form_w()
 	XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
 	XtSetArg (args[n], XmNrightWidget, limmag_w); n++;
 	XtSetArg (args[n], XmNshadowType, XmSHADOW_ETCHED_OUT); n++;
-	frame_w = XmCreateFrame (jupform_w, "JupFrame", args, n);
-	XtManageChild (frame_w);
+	jmframe_w = XmCreateFrame (jupform_w, "JupFrame", args, n);
+	XtManageChild (jmframe_w);
 
 	    /* make a drawing area for drawing the little map */
 
 	    n = 0;
-	    jda_w = XmCreateDrawingArea (frame_w, "Map", args, n);
+	    jda_w = XmCreateDrawingArea (jmframe_w, "Map", args, n);
 	    XtAddCallback (jda_w, XmNexposeCallback, jm_da_exp_cb, 0);
-	    XtAddCallback (jda_w, XmNinputCallback, jm_da_input_cb, 0);
+	    XtAddCallback (jda_w, XmNinputCallback, jm_da_input_cb, 
+	    						(XtPointer)SO_MAIN);
 	    XtManageChild (jda_w);
 }
 
@@ -548,6 +566,10 @@ jm_create_jsform_w()
 	    char *tip;		/* widget tip */
 	} MoonColumn;
 	static MoonColumn mc[] = {
+	    {CEV,   "UEV",   "E",     "EVis",
+		"Whether geometrically visible from Earth"},
+	    {CSV,   "USV",   "S",     "SVis",
+		"Whether in Sun light"},
 	    {CX,   "JupX",   "X (+E)",     "X",
 		"Apparent displacement east of planetary center"},
 	    {CY,   "JupY",   "Y (+S)",     "Y",
@@ -818,6 +840,48 @@ jm_create_jsform_w()
 	XtManageChild (w);
 }
 
+/* create jtform_w, the top view dialog */
+static void
+jm_create_tvform_w()
+{
+	Arg args[20];
+	int n;
+
+	/* create form */
+	n = 0;
+	XtSetArg (args[n], XmNautoUnmanage, False); n++;
+	XtSetArg (args[n], XmNdefaultPosition, False); n++;
+	XtSetArg (args[n], XmNcolormap, xe_cm); n++;
+	jtform_w = XmCreateFormDialog (toplevel_w, "JupiterTV", args, n);
+	set_something (jtform_w, XmNcolormap, (XtArgVal)xe_cm);
+	XtAddCallback (jtform_w, XmNunmapCallback, jt_unmap_cb, 0);
+	XtAddCallback (jtform_w, XmNmapCallback, jt_map_cb, NULL);
+
+	/* set some stuff in the parent DialogShell.
+	 * setting XmNdialogTitle in the Form didn't work..
+	 */
+	n = 0;
+	XtSetArg (args[n], XmNtitle, "xephem Jupiter top view"); n++;
+	XtSetValues (XtParent(jtform_w), args, n);
+
+	/* fill with a drawing area in a frame */
+
+	n = 0;
+	XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	jtframe_w = XmCreateFrame (jtform_w, "JTVF", args, n);
+	XtManageChild (jtframe_w);
+
+	    n = 0;
+	    jtda_w = XmCreateDrawingArea (jtframe_w, "Map", args, n);
+	    XtAddCallback (jtda_w, XmNexposeCallback, jt_da_exp_cb, NULL);
+	    XtAddCallback (jtda_w, XmNinputCallback, jm_da_input_cb, 
+							(XtPointer)SO_TOP);
+	    XtManageChild (jtda_w);
+}
+
 /* go through all the buttons pickable for plotting and set whether they
  * should appear to look like buttons or just flat labels.
  */
@@ -947,8 +1011,18 @@ Widget w;
 XtPointer client;
 XtPointer call;
 {
-	if (client)
-	    *((int *)client) = XmToggleButtonGetState(w);
+	if (client) {
+	    int *flagp = (int *)client;
+	    *flagp = XmToggleButtonGetState(w);
+	    if (flagp == &topview) {
+		if (topview) {
+		    if (!jtform_w)
+			jm_create_tvform_w();
+		    XtManageChild (jtform_w);
+		} else
+		    XtUnmanageChild (jtform_w);
+	    }
+	}
 
 	jm_update (mm_get_now(), 1);
 }
@@ -982,6 +1056,131 @@ XtPointer call;
 	}
 }
 
+/* callback from either expose or resize of the topview.
+ */
+/* ARGSUSED */
+static void
+jt_da_exp_cb (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	static int last_nx, last_ny;
+	XmDrawingAreaCallbackStruct *c = (XmDrawingAreaCallbackStruct *)call;
+        Window win = XtWindow(w);
+	Display *dsp = XtDisplay(w);
+	unsigned int nx, ny, bw, d;
+	Window root;
+	int x, y;
+
+	/* filter out a few oddball cases */
+	switch (c->reason) {
+	case XmCR_EXPOSE: {
+	    /* turn off gravity so we get expose events for either shrink or
+	     * expand.
+	     */
+	    static int before;
+	    XExposeEvent *e = &c->event->xexpose;
+
+	    if (!before) {
+		XSetWindowAttributes swa;
+                unsigned long mask = CWBitGravity | CWBackingStore;
+
+		swa.bit_gravity = ForgetGravity;
+		swa.backing_store = NotUseful; /* we use a pixmap */
+		XChangeWindowAttributes (dsp, win, mask, &swa);
+		before = 1;
+	    }
+
+	    /* wait for the last in the series */
+	    if (e->count != 0)
+		return;
+	    break;
+	    }
+	default:
+	    printf ("Unexpected jupform_w event. type=%d\n", c->reason);
+	    exit(1);
+	}
+
+        XGetGeometry(dsp, win, &root, &x, &y, &nx, &ny, &bw, &d);
+	if (!jt_pm || nx != last_nx || ny != last_ny) {
+	    if (jt_pm)
+		XFreePixmap (dsp, jt_pm);
+	    jt_pm = XCreatePixmap (dsp, win, nx, ny, d);
+	    last_nx = nx;
+	    last_ny = ny;
+	    jt_track_size();
+	    jm_update (mm_get_now(), 1);
+	} else
+	    XCopyArea (dsp, jt_pm, win, j_fgc, 0, 0, nx, ny, 0, 0);
+}
+
+/* called whenever the topview scene is mapped. */
+/* ARGSUSED */
+static void
+jt_map_cb (wid, client, call)
+Widget wid;
+XtPointer client;
+XtPointer call;
+{
+	jt_track_size();
+}
+
+/* set the width of the topview DrawingArea the same as the main window's.
+ * we also try to center it just above, but it doesn't always work.
+ */
+static void
+jt_track_size()
+{
+	Dimension w, h;
+	Position mfx, mfy, mdx, mdy;
+	Position sdy;
+	Arg args[20];
+	int n;
+
+	/* set widths equal */
+	n = 0;
+	XtSetArg (args[n], XmNwidth, &w); n++;
+	XtGetValues (jda_w, args, n);
+
+	n = 0;
+	XtSetArg (args[n], XmNwidth, w); n++;
+	XtSetValues (jtda_w, args, n);
+
+	n = 0;
+	XtSetArg (args[n], XmNheight, &h); n++;
+	XtGetValues (jtda_w, args, n);
+
+	/* set locations -- allow for different stuff on top of drawingareas */
+	n = 0;
+	XtSetArg (args[n], XmNx, &mfx); n++;
+	XtSetArg (args[n], XmNy, &mfy); n++;
+	XtGetValues (jupform_w, args, n);
+	n = 0;
+	XtSetArg (args[n], XmNx, &mdx); n++;
+	XtSetArg (args[n], XmNy, &mdy); n++;
+	XtGetValues (jmframe_w, args, n);
+	n = 0;
+	XtSetArg (args[n], XmNy, &sdy); n++;
+	XtGetValues (jtframe_w, args, n);
+
+	n = 0;
+	XtSetArg (args[n], XmNx, mfx+mdx); n++;
+	XtSetArg (args[n], XmNy, mfy - h - sdy - mdy - 20); n++;
+	XtSetValues (jtform_w, args, n);
+}
+
+/* callback when topview dialog is unmapped */
+/* ARGSUSED */
+static void
+jt_unmap_cb (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	XmToggleButtonSetState (topview_w, False, True);
+}
+
 /* callback when main dialog is unmapped */
 /* ARGSUSED */
 static void
@@ -997,6 +1196,10 @@ XtPointer call;
 	    jm_pm = (Pixmap) NULL;
 	}
 
+	/* close top view */
+	if (jtform_w && XtIsManaged(jtform_w))
+	    XtUnmanageChild (jtform_w);
+
 	/* free any field stars */
 	if (fstars) {
 	    free ((void *)fstars);
@@ -1045,7 +1248,7 @@ Widget w;
 XtPointer client;
 XtPointer call;
 {
-	static last_nx, last_ny;
+	static int last_nx, last_ny;
 	XmDrawingAreaCallbackStruct *c = (XmDrawingAreaCallbackStruct *)call;
 	Window win = XtWindow(w);
 	Display *dsp = XtDisplay(w);
@@ -1059,7 +1262,7 @@ XtPointer call;
 	    /* turn off gravity so we get expose events for either shrink or
 	     * expand.
 	     */
-	    static before;
+	    static int before;
 	    XExposeEvent *e = &c->event->xexpose;
 
 	    if (!before) {
@@ -1084,15 +1287,21 @@ XtPointer call;
 
 	XGetGeometry(dsp, win, &root, &x, &y, &nx, &ny, &bw, &d);
 	if (!jm_pm || nx != last_nx || ny != last_ny) {
+	    if (jm_pm)
+		XFreePixmap (dsp, jm_pm);
 	    jm_pm = XCreatePixmap (dsp, win, nx, ny, d);
 	    last_nx = nx;
 	    last_ny = ny;
+	    if (topview)
+		jt_track_size();
 	    jm_update (mm_get_now(), 1);
 	} else
 	    XCopyArea (dsp, jm_pm, win, j_fgc, 0, 0, nx, ny, 0, 0);
 }
 
-/* callback from mouse or keyboard input over drawing area */
+/* callback from mouse or keyboard input over either drawing area.
+ * client is one of SOIdx.
+ */
 /* ARGSUSED */
 static void
 jm_da_input_cb (w, client, call)
@@ -1101,8 +1310,9 @@ XtPointer client;
 XtPointer call;
 {
 	XmDrawingAreaCallbackStruct *c = (XmDrawingAreaCallbackStruct *)call;
-	XEvent *ev;
 	ScreenObj *sop;
+	SOIdx soidx;
+	XEvent *ev;
 	int x, y;
 
 	/* get x and y value iff it was from mouse button 3 */
@@ -1115,11 +1325,12 @@ XtPointer call;
 	y = ev->xbutton.y;
 
 	/* find something close on the screen */
-	sop = close_screenobj (x, y);
+	soidx = (SOIdx) client;
+	sop = close_screenobj (soidx, x, y);
 	if (!sop)
 	    return;
 
-	/* put info in popup, jmpu_w, creating it first is necessary  */
+	/* put info in popup, jmpu_w, creating it first if necessary  */
 	if (!jmpu_w)
 	    jm_create_popup();
 	jm_fill_popup (sop);
@@ -1229,22 +1440,23 @@ XtPointer call;
 	(void) skyloc_fifo (op);
 }
 
-/* add one entry to the global screenobj array.
+/* add one entry to the given global screenobj array.
  */
 static void
-add_screenobj (op, x, y)
+add_screenobj (soidx, op, x, y)
+SOIdx soidx;
 Obj *op;
 int x, y;
 {
-	ScreenObj *mem;
+	char *mem = (char *) screenobj[soidx];
+	int nmem = nscreenobj[soidx];
 	ScreenObj *sop;
 
 	/* grow screenobj by one */
-	if (screenobj)
-	    mem = (ScreenObj *) realloc ((char *)screenobj,
-					    (nscreenobj+1)*sizeof (ScreenObj));
+	if (mem)
+	    mem = realloc ((char *)mem, (nmem+1)*sizeof(ScreenObj));
 	else
-	    mem = (ScreenObj *) malloc (sizeof (ScreenObj));
+	    mem = malloc (sizeof(ScreenObj));
 	if (!mem) {
 	    char msg[256];
 	    (void) sprintf (msg, "Out of memory -- %s will not be pickable",
@@ -1252,9 +1464,9 @@ int x, y;
 	    xe_msg (msg, 0);
 	    return;
 	}
-	screenobj = mem;
+	screenobj[soidx] = (ScreenObj *) mem;
 
-	sop = &screenobj[nscreenobj++];
+	sop = &screenobj[soidx][nscreenobj[soidx]++];
 
 	/* fill new entry */
 	sop->o = *op;
@@ -1262,29 +1474,34 @@ int x, y;
 	sop->y = y;
 }
 
-/* reclaim any existing screenobj entries */
+/* reclaim any existing screenobj entries from the given collection */
 static void
-reset_screenobj()
+reset_screenobj(soidx)
+SOIdx soidx;
 {
-	if (screenobj) {
-	    free ((char *)screenobj);
-	    screenobj = NULL;
+	if (screenobj[soidx]) {
+	    free ((char *)screenobj[soidx]);
+	    screenobj[soidx] = NULL;
 	}
-	nscreenobj = 0;
+	nscreenobj[soidx] = 0;
 }
 
-/* find the entry in screenobj closest to [x,y] within MINR.
+/* find the entry in the given screenobj closest to [x,y] within MINR.
  * if found return the ScreenObj *, else NULL.
  */
 static ScreenObj *
-close_screenobj (x, y)
+close_screenobj (soidx, x, y)
+SOIdx soidx;
 int x, y;
 {
-	int minr;
-	ScreenObj *sop, *minsop = NULL;
+	ScreenObj *scop = screenobj[soidx];
+	ScreenObj *minsop = NULL;
+	int nobj = nscreenobj[soidx];
+	int minr = 2*MINR;
+	int i;
 
-	minr = 2*MINR;
-	for (sop = &screenobj[nscreenobj]; --sop >= screenobj; ) {
+	for (i = 0; i < nobj; i++) {
+	    ScreenObj *sop = &scop[i];
 	    int r = abs(x - sop->x) + abs(y - sop->y);
 	    if (r < minr) {
 		minr = r;
@@ -1301,6 +1518,8 @@ typedef struct {
     double x, y, z;	/* radii: +x:east +y:south +z:front */
     double ra, dec;
     double mag;
+    int evis;		/* geometrically visible from earth */
+    int svis;		/* in sun light */
 } MoonData;
 
 /* functions */
@@ -1309,6 +1528,53 @@ static void moonradec();
 static void jm_draw_map ();
 static void make_gcs ();
 
+/* set svis according to whether moon is in sun light */
+static void
+moonSVis(op, mdp)
+Obj *op;
+MoonData *mdp;
+{
+	Obj *eop = db_basic (SUN);
+	double esd = eop->s_edist;
+	double eod = op->s_edist;
+	double sod = op->s_sdist;
+	double soa = degrad(op->s_elong);
+	double esa = asin(esd*sin(soa)/sod);
+	double   h = sod*op->s_hlat;
+	double nod = h*(1./eod - 1./sod);
+	double xp, yp, zp;
+	double xpp, ypp, zpp;
+	double ca, sa;
+	int outside;
+	int infront;
+
+	ca = cos(esa);
+	sa = sin(esa);
+	xp =  ca*mdp->x + sa*mdp->z;
+	yp =  mdp->y;
+	zp = -sa*mdp->x + ca*mdp->z;
+
+	ca = cos(nod);
+	sa = sin(nod);
+	xpp = xp;
+	ypp = ca*yp - sa*zp;
+	zpp = sa*yp + ca*zp;
+
+	outside = xpp*xpp + ypp*ypp > 1.0;
+	infront = zpp > 0.0;
+	mdp->svis = outside || infront;
+}
+
+/* set evis according to whether moon is geometrically visible from earth */
+static void
+moonEVis (mdp)
+MoonData *mdp;
+{
+	int outside = mdp->x*mdp->x + mdp->y*mdp->y > 1.0;
+	int infront = mdp->z > 0.0;
+	mdp->evis = outside || infront;
+}
+
 /* called to recompute and fill in values for the jupiter menu.
  * don't bother if it doesn't exist or is unmanaged now or no one is logging.
  */
@@ -1318,13 +1584,11 @@ Now *np;
 int how_much;
 {
 	static char fmt[] = "%7.3f";
+	Obj *jop = db_basic (JUPITER);
 	MoonData md[NM];
 	int wantstats;
 	double cmlI, cmlII;
 	double jupsize;
-	double theta, phi;
-	double tvc, pvc;
-	double salpha, calpha;
 	int i;
 
 	/* see if we should bother */
@@ -1337,21 +1601,25 @@ int how_much;
 	watch_cursor (1);
 
         /* compute md[0].x/y/z/mag/ra/dec and md[1..NM-1].x/y/z/mag info */
-        jupiter_data(mjd, &jupsize, &cmlI, &cmlII, md);
+        jupiter_data(mjd, jop, &jupsize, &cmlI, &cmlII, md);
 
-	/* compute sky transformation angle as triple vector product */
-	tvc = PI/2.0 - md[0].dec;
-	pvc = md[0].ra;
-	theta = PI/2 - POLE_DEC;
-	phi = POLE_RA;
-	salpha = sin(tvc)*sin(theta)*(cos(pvc)*sin(phi) - sin(pvc)*cos(phi));
-	calpha = sqrt (1.0 - salpha*salpha);
+	/* set md[0..NM-1].evis */
+	md[0].evis = 1;
+	for (i = 1; i < NM; i++)
+	    moonEVis (&md[i]);
+
+	/* set md[0..NM-1].svis */
+	md[0].svis = 1;
+	for (i = 1; i < NM; i++)
+	    moonSVis (jop, &md[i]);
 
         /* find md[1..NM-1].ra/dec from md[0].ra/dec and md[1..NM-1].x/y */
-	moonradec (jupsize, salpha, calpha, md);
+	moonradec (jupsize, md);
 
 	if (wantstats) {
 	    for (i = 0; i < NM; i++) {
+		f_double (j_w[i][CEV], "%1.0f", (double)md[i].evis);
+		f_double (j_w[i][CSV], "%1.0f", (double)md[i].svis);
 		f_double (j_w[i][CX], fmt, md[i].x);
 		f_double (j_w[i][CY], fmt, md[i].y);
 		f_double (j_w[i][CZ], fmt, md[i].z);
@@ -1366,7 +1634,7 @@ int how_much;
 	}
 
 	if (XtIsManaged(jupform_w)) {
-	    jm_draw_map (jda_w, jupsize, salpha, calpha, cmlII, md);
+	    jm_draw_map (jda_w, jop, jupsize, cmlII, md);
 	    timestamp (np, dt_w);
 	}
 
@@ -1383,15 +1651,21 @@ int how_much;
  *     +md[].z: in front, jup radii
  */
 static void
-jm_draw_map (w, jupsize, salpha, calpha, cmlII, md)
+jm_draw_map (w, jop, jupsize, cmlII, md)
 Widget w;
+Obj *jop;
 double jupsize;
-double salpha, calpha;
 double cmlII;
 MoonData md[NM];
 {
+#define	NORM	27.0	/* max Callisto orbit radius; used to normalize */
+#define	MAPSCALE(r)	((r)*((int)nx)/NORM/2*scale)
+#define	XCORD(x)	((int)(((int)nx)/2.0 + ew*MAPSCALE(x) + 0.5))
+#define	YCORD(y)	((int)(((int)ny)/2.0 - ns*MAPSCALE(y) + 0.5))
+#define ZCORD(z)        ((int)(((int)ny)/2.0 +    MAPSCALE(z) + 0.5))
+
 	Display *dsp = XtDisplay(w);
-	Window win = XtWindow(w);
+	Window win;
 	Window root;
 	double scale;
 	int sv;
@@ -1402,12 +1676,11 @@ MoonData md[NM];
 	unsigned int nx, ny, bw, d;
 	int ns = flip_tb ? -1 : 1;
 	int ew = flip_lr ? -1 : 1;
+	int scale1;
 	int i;
 
-#define	NORM	27.0	/* max Callisto orbit radius; used to normalize */
-#define	MAPSCALE(r)	((r)*((int)nx)/NORM/2*scale)
-#define	XCORD(x)	((int)(((int)nx)/2.0 + ew*MAPSCALE(x) + 0.5))
-#define	YCORD(y)	((int)(((int)ny)/2.0 - ns*MAPSCALE(y) + 0.5))
+	/* first the main graphic */
+	win = XtWindow (jda_w);
 
 	if (!j_fgc)
 	    make_gcs(w);
@@ -1416,17 +1689,18 @@ MoonData md[NM];
 	XmScaleGetValue (scale_w, &sv);
 	scale = pow(MAXSCALE, sv/100.0);
 
+	/* get size and erase */
 	XGetGeometry(dsp, win, &root, &x, &y, &nx, &ny, &bw, &d);
-
 	XFillRectangle (dsp, jm_pm, j_bgc, 0, 0, nx, ny);
+	scale1 = (int)floor(MAPSCALE(1)+0.5);
 
 	/* prepare for a new list of things on the screen */
-	reset_screenobj();
+	reset_screenobj(SO_MAIN);
 
 	/* draw background objects, if desired */
 	if (skybkg)
-	    sky_background(jm_pm, nx, ny, fmag, md[0].ra, md[0].dec, salpha,
-		calpha, jupsize/MAPSCALE(2), jupsize*NORM, flip_tb, flip_lr);
+	    sky_background(jm_pm, nx, ny, fmag, md[0].ra, md[0].dec,
+			jupsize/MAPSCALE(2), jupsize*NORM, flip_tb, flip_lr);
 
 	/* draw labels */
 	c = flip_lr ? 'W' : 'E';
@@ -1435,14 +1709,13 @@ MoonData md[NM];
 	XDrawString(dsp, jm_pm, j_fgc, (nx-j_cw)/2-1, j_fs->ascent, &c, 1);
 
 	/* draw Jupiter in center with unit radius */
-	XPSFillArc(dsp,jm_pm, j_fgc, nx/2-(int)MAPSCALE(1),
-					ny/2-(int)MAPSCALE(1), (int)MAPSCALE(2),
-					(int)MAPSCALE(2), 0, 360*64);
-	add_screenobj (db_basic(JUPITER), nx/2, ny/2);
+	XPSFillArc(dsp, jm_pm, j_fgc, nx/2-scale1, ny/2-scale1, 2*scale1-1,
+						    2*scale1-1, 0, 360*64);
+	add_screenobj (SO_MAIN, jop, nx/2, ny/2);
 
 	/* draw the GRS */
 	grslstr = XmTextFieldGetString (grsl_w);
-	jgrs_draw (jm_pm, (int)MAPSCALE(1), nx/2, ny/2, flip_tb,flip_lr,
+	jgrs_draw (jop, jm_pm, scale1, nx/2, ny/2, flip_tb, flip_lr,
 						degrad(atod (grslstr)), cmlII);
 	XtFree (grslstr);
 
@@ -1456,16 +1729,13 @@ MoonData md[NM];
 	for (i = 1; i < NM; i++) {
 	    double mx = md[i].x;
 	    double my = md[i].y;
-	    double mz = md[i].z;
 	    double mag = md[i].mag;
-	    int outside = mx*mx + my*my > 1.0;
-	    int infront = mz > 0.0;
 	    int diam;
 	    Obj o;
 
-	    if (!outside && !infront)
+	    if (!md[i].evis)
 		continue;	/* behind jupiter */
-	    diam = magdiam (fmag, 1, jupsize/MAPSCALE(2), mag, 0.0);
+	    diam = magdiam (fmag, 1, jupsize/(2*scale1), mag, 0.0);
 	    if (brmoons)
 		diam += 3;
 	    if (diam <= 0)
@@ -1484,7 +1754,7 @@ MoonData md[NM];
 	    set_smag (&o, mag);
 	    o.s_ra = md[i].ra;
 	    o.s_dec = md[i].dec;
-	    add_screenobj (&o, x, y);
+	    add_screenobj (SO_MAIN, &o, x, y);
 
 	    if (tags && mnames[i].tag)
 		XDrawString(dsp, jm_pm, j_xgc, x-j_cw/2, y+2*j_ch,
@@ -1492,6 +1762,76 @@ MoonData md[NM];
 	}
 
 	XCopyArea (dsp, jm_pm, win, j_fgc, 0, 0, nx, ny, 0, 0);
+
+	/* then the top view, if desired */
+
+	if (!topview || !jt_pm)	/* let expose make new pixmap */
+	    return;
+
+	/* get size and erase */
+	win = XtWindow (jtda_w);
+	XGetGeometry(dsp, win, &root, &x, &y, &nx, &ny, &bw, &d);
+	XFillRectangle (dsp, jt_pm, j_bgc, 0, 0, nx, ny);
+
+	/* draw jupiter in center with unit radius */
+	i = ew*64*raddeg(asin(sin(degrad(jop->s_elong))/jop->s_sdist));
+	XPSFillArc(dsp, jt_pm, j_fgc, nx/2-scale1, ny/2-scale1, 2*scale1-1,
+						    2*scale1-1, -i, -180*64);
+	reset_screenobj(SO_TOP);
+	add_screenobj (SO_TOP, jop, nx/2, ny/2);
+
+	/* draw each moon
+	 */
+	for (i = 1; i < NM; i++) {
+	    double mx = md[i].x;
+	    double mz = md[i].z;
+	    double mag = md[i].mag;
+	    int diam;
+	    Obj o;
+
+	    if (!md[i].svis)
+		continue;
+
+	    diam = magdiam (fmag, 1, jupsize/(2*scale1), mag, 0.0);
+	    if (brmoons)
+		diam += 3;
+	    if (diam <= 0)
+		continue;	/* too faint */
+
+	    x = XCORD(mx);
+	    y = ZCORD(mz);
+	    if (diam == 1)
+		XDrawPoint (dsp, jt_pm, j_xgc, x, y);
+	    else
+		XPSFillArc (dsp, jt_pm, j_xgc, x-diam/2, y-diam/2, diam, diam,
+								    0, 360*64);
+
+	    /* add object to list of screen objects drawn */
+	    (void) strcpy (o.o_name, mnames[i].full);
+	    set_smag (&o, mag);
+	    o.s_ra = md[i].ra;
+	    o.s_dec = md[i].dec;
+	    add_screenobj (SO_TOP, &o, x, y);
+
+	    if (tags && mnames[i].tag)
+		XDrawString(dsp, jt_pm, j_xgc, x-j_cw/2, y+2*j_ch,
+					mnames[i].tag, strlen(mnames[i].tag));
+	}
+
+	/* draw label towards earth */
+	if (tags) {
+	    XPoint xp[5];
+
+	    XDrawString(dsp, jt_pm, j_fgc, nx/2, ny-j_ch, "Earth", 5);
+	    xp[0].x = nx/2 - 15; xp[0].y = ny - 2*j_ch;
+	    xp[1].x = 0;         xp[1].y = 3*j_ch/2;
+	    xp[2].x = -5;        xp[2].y = -3*j_ch/4;
+	    xp[3].x = 10;        xp[3].y = 0;
+	    xp[4].x = -5;        xp[4].y = 3*j_ch/4;
+	    XDrawLines (dsp, jt_pm, j_fgc, xp, 5, CoordModePrevious);
+	}
+
+	XCopyArea (dsp, jt_pm, win, j_fgc, 0, 0, nx, ny, 0, 0);
 }
 
 static void
@@ -1552,24 +1892,23 @@ int l;
 	XDrawString (dsp, win, gc, xc-tw/2, yc+th, tag, strlen(tag));
 }
 
-/* draw all database objects in a small sky patch with the given orientation.
+/* draw all database objects in a small sky patch about the given center.
  * get field stars too if enabled and we have moved enough.
  * save objects and screen locs in the global screenobj array for picking.
  * this is used to draw the backgrounds for the planet closeups.
  * Based on work by: Dan Bruton <WDB3926@acs.tamu.edu>
  */
 static void
-sky_background (win, w, h, fmag, ra0,dec0,salpha,calpha,scale,rad,fliptb,fliplr)
+sky_background (win, w, h, fmag, ra0,dec0,scale,rad,fliptb,fliplr)
 Drawable win;		/* window to draw on */
 unsigned w, h;		/* window size */
 int fmag;		/* faintest magnitude to display */
 double ra0, dec0;	/* center of patch, rads */
-double salpha, calpha;	/* transformation parameters */
 double scale;		/* rads per pixel */
 double rad;		/* maximum radius to draw away from ra0/dec0, rads */
 int fliptb, fliplr;	/* flip direction; default is S up E right */
 {
-	static before;
+	static int before;
 	double cdec0 = cos(dec0);
 	DBScan dbs;
 	Obj *op;
@@ -1599,7 +1938,7 @@ int fliptb, fliplr;	/* flip direction; default is S up E right */
 
 	    /* find size, in pixels. */
 	    diam = magdiam (fmag, 1, scale, get_mag(op),
-					    degrad((double)op->s_size/3600.0));
+						    degrad(op->s_size/3600.0));
 	    if (diam <= 0)
 		continue;
 
@@ -1608,8 +1947,8 @@ int fliptb, fliplr;	/* flip direction; default is S up E right */
 	    ddec = dec0 - op->s_dec;	/* + S */
 	    if (fabs(ddec) > rad || delra(dra)*cdec0 > rad)
 		continue;
-	    dx = (dra*calpha - ddec*salpha)/scale;
-	    dy = (dra*salpha + ddec*calpha)/scale;
+	    dx = dra/scale;
+	    dy = ddec/scale;
 	    x = fliplr ? (int)w/2-dx : (int)w/2+dx;
 	    y = fliptb ? (int)h/2+dy : (int)h/2-dy;
 
@@ -1620,7 +1959,7 @@ int fliptb, fliplr;	/* flip direction; default is S up E right */
 	    sv_draw_obj (XtD, win, gc, op, x, y, diam, 0);
 
 	    /* save 'er */
-	    add_screenobj (op, x, y);
+	    add_screenobj (SO_MAIN, op, x, y);
 	}
 
 	sv_draw_obj (XtD, win, (GC)0, NULL, 0, 0, 0, 0);	/* flush */
@@ -1659,9 +1998,8 @@ double ra, dec;
  * md[1..NM-1].x/y in jup radii, find ra/dec of each moon in md[1..NM-1].ra/dec.
  */
 static void
-moonradec (jupsize, salpha, calpha, md)
+moonradec (jupsize, md)
 double jupsize;		/* jup diameter, rads */
-double salpha, calpha;	/* transormation parameters */
 MoonData md[NM];	/* fill in RA and Dec */
 {
 	double juprad = jupsize/2;
@@ -1670,8 +2008,8 @@ MoonData md[NM];	/* fill in RA and Dec */
 	int i;
 
 	for (i = 1; i < NM; i++) {
-	    double dra  = juprad * ( md[i].x*calpha + md[i].y*salpha);
-	    double ddec = juprad * (-md[i].x*salpha + md[i].y*calpha);
+	    double dra  = juprad * md[i].x;
+	    double ddec = juprad * md[i].y;
 	    md[i].ra  = jupra + dra;
 	    md[i].dec = jupdec - ddec;
 	}
@@ -1682,7 +2020,8 @@ MoonData md[NM];	/* fill in RA and Dec */
  *   right to left. Spot is in S hemisphere. CML increases with time.
  */
 static void
-jgrs_draw (dr, rad, jx, jy, fliptb, fliplr, jgrs_lng, cmlII)
+jgrs_draw (jop, dr, rad, jx, jy, fliptb, fliplr, jgrs_lng, cmlII)
+Obj *jop;	/* jupiter info */
 Drawable dr;	/* drawable to use */
 int rad;	/* radius of jupiter, pixels */
 int jx, jy;	/* center of jupiter circle, dr coords */
@@ -1696,6 +2035,8 @@ double cmlII;	/* current central merdian longitude, system II, rads */
 	int r;		/* radius of GRS, pixels */
 	int h, w;	/* h is always r, but we flatten w at limbs */
 	double a;	/* angle from center to GRS going towards right (+E) */
+	double tvc, pvc, theta, phi;	/* for sky-plane rotation */
+	double dxp, dyp;
 	double ca, sa;
 
 	a = jgrs_lng - cmlII;
@@ -1711,8 +2052,18 @@ double cmlII;	/* current central merdian longitude, system II, rads */
 	dx = rad*sa;	/* E right */
 	dy = -r;	/* S up */
 
-	x = fliplr ? jx - dx : jx + dx;
-	y = fliptb ? jy - dy : jy + dy;
+	tvc = PI/2.0 - jop->s_dec;
+	pvc = jop->s_ra;
+	theta = PI/2.0 - POLE_DEC;
+	phi = POLE_RA;
+	sa = sin(tvc)*sin(theta)*(cos(pvc)*sin(phi) - sin(pvc)*cos(phi));
+	ca = sqrt (1.0 - sa*sa);
+
+	dxp =  dx*ca + dy*sa;
+	dyp = -dx*sa + dy*ca;
+
+	x = fliplr ? jx - dxp : jx + dxp;
+	y = fliptb ? jy - dyp : jy + dyp;
 
 	if (w > 0 && h > 0)
 	    XFillArc (XtD, dr, jgrs_gc, x-w/2, y-h/2, w, h, 0, 360*64);
@@ -1721,6 +2072,10 @@ double cmlII;	/* current central merdian longitude, system II, rads */
 #define	dsin(x)	sin(degrad(x))
 #define	dcos(x)	cos(degrad(x))
 
+static int use_bdl P_((double jd, MoonData md[NM]));
+static void meeus_jupiter P_((double d, double *cmlI, double *cmlII,
+    MoonData md[NM]));
+
 /* given a modified julian date (ie, days since Jan .5 1900), d, return x, y, z
  *   location of each Galilean moon as a multiple of Jupiter's radius. on this
  *   scale, Callisto is never more than 26.5593. +x is easterly, +y is
@@ -1730,17 +2085,65 @@ double cmlII;	/* current central merdian longitude, system II, rads */
  *   in degress, relative to the true disk of jupiter and corrected for light
  *   travel time. also return jupiter ra/dec/mag in md[0] and diam, in rads.
  *   also return nominal magnitude of each moon.
- * from "Astronomical Formulae for Calculators", 2nd ed, by Jean Meeus,
- *   Willmann-Bell, Richmond, Va., U.S.A. (c) 1982, chapters 35 and 36.
  */
 static void
-jupiter_data(d, jupsize, cmlI, cmlII, md)
+jupiter_data(d, jop, jupsize, cmlI, cmlII, md)
 double d;
+Obj *jop;
 double *jupsize;
 double *cmlI, *cmlII;	/* central meridian longitude, rads */
 MoonData md[NM];	/* fill in md[0].ra/dec/mag/x/y/z for jupiter,
 			 * md[1..NM-1].x/y/z/mag for each moon
 			 */
+{
+        static int using_bdl = -1; /* log which model, but only when changes */
+
+	md[0].ra = jop->s_ra;
+	md[0].dec = jop->s_dec;
+	md[0].mag = get_mag(jop);
+
+	md[0].x = 0;
+	md[0].y = 0;
+	md[0].z = 0;
+
+	*jupsize = degrad(jop->s_size/3600.0);
+
+	/* from Pasachoff/Menzel */
+
+	md[1].mag = 5.0;
+	md[2].mag = 5.3;
+	md[3].mag = 4.6;
+	md[4].mag = 5.6;
+
+	/* get moon data from BDL if possible, else Meeus' model */
+
+	if (use_bdl (d+MJD0, md) == 0) {
+	    if (using_bdl != 1) {
+		xe_msg ("Using BDL model for Galilean moons", 0);
+		using_bdl = 1;
+	    }
+	    meeus_jupiter (d, cmlI, cmlII, NULL);
+	} else {
+	    if (using_bdl != 0) {
+		xe_msg ("Using Meeus model for Galilean moons", 0);
+		using_bdl = 0;
+	    }
+	    meeus_jupiter (d, cmlI, cmlII, md);
+	}
+}
+
+/* computer location of GRS and Galilean moons.
+ * if md == NULL, don't do moons.
+ * from "Astronomical Formulae for Calculators", 2nd ed, by Jean Meeus,
+ *   Willmann-Bell, Richmond, Va., U.S.A. (c) 1982, chapters 35 and 36.
+ */
+static void
+meeus_jupiter(d, cmlI, cmlII, md)
+double d;
+double *cmlI, *cmlII;	/* central meridian longitude, rads */
+MoonData md[NM];	/* fill in md[1..NM-1].x/y/z for each moon.
+			 * N.B. md[0].ra/dec must already be set
+			 */
 {
 	double A, B, Del, J, K, M, N, R, V;
 	double cor_u1, cor_u2, cor_u3, cor_u4;
@@ -1749,6 +2152,10 @@ MoonData md[NM];	/* fill in md[0].ra/dec/mag/x/y/z for jupiter,
 	double lam, Ds;
 	double z1, z2, z3,  z4;
 	double De, dsinDe;
+	double theta, phi;
+	double tvc, pvc;
+	double salpha, calpha;
+	int i;
 
 	V = 134.63 + 0.00111587 * d;
 
@@ -1765,6 +2172,15 @@ MoonData md[NM];	/* fill in md[0].ra/dec/mag/x/y/z for jupiter,
 	Del = sqrt (R*R + r*r - 2*R*r*dcos(K));
 	psi = raddeg (asin (R/Del*dsin(K)));
 
+	*cmlI  = degrad(268.28 + 877.8169088*(d - Del/173) + psi - B);
+	range (cmlI, 2*PI);
+	*cmlII = degrad(290.28 + 870.1869088*(d - Del/173) + psi - B);
+	range (cmlII, 2*PI);
+
+	/* that's it if don't want moon info too */
+	if (!md)
+	    return;
+
 	solc = (d - Del/173.);	/* speed of light correction */
 	tmp = psi - B;
 
@@ -1807,32 +2223,77 @@ MoonData md[NM];	/* fill in md[0].ra/dec/mag/x/y/z for jupiter,
 	md[3].y = z3*dsinDe;
 	md[4].y = z4*dsinDe;
 
+	/* compute sky transformation angle as triple vector product */
+	tvc = PI/2.0 - md[0].dec;
+	pvc = md[0].ra;
+	theta = PI/2.0 - POLE_DEC;
+	phi = POLE_RA;
+	salpha = -sin(tvc)*sin(theta)*(cos(pvc)*sin(phi) - sin(pvc)*cos(phi));
+	calpha = sqrt (1.0 - salpha*salpha);
+
+	for (i = 0; i < NM; i++) {
+	    double tx =  md[i].x*calpha + md[i].y*salpha;
+	    double ty = -md[i].x*salpha + md[i].y*calpha;
+	    md[i].x = tx;
+	    md[i].y = ty;
+	}
+
 	md[1].z = z1;
 	md[2].z = z2;
 	md[3].z = z3;
 	md[4].z = z4;
-
-	md[1].mag = 5.0;	/* from Pasachoff/Menzel */
-	md[2].mag = 5.3;
-	md[3].mag = 4.6;
-	md[4].mag = 5.6;
-
-	*cmlI  = degrad(268.28 + 877.8169088*(d - Del/173) + psi - B);
-	range (cmlI, 2*PI);
-	*cmlII = degrad(290.28 + 870.1869088*(d - Del/173) + psi - B);
-	range (cmlII, 2*PI);
-
-	{
-	    Obj *op = db_basic (JUPITER);
-
-	    md[0].x = 0;
-	    md[0].y = 0;
-	    md[0].z = 0;
-	    md[0].mag = get_mag(op);
-
-	    md[0].ra = op->s_ra;
-	    md[0].dec = op->s_dec;
-
-	    *jupsize = degrad((double)op->s_size/3600.0);
-	}
 }
+
+/* hunt for BDL file. return 0 if ok, else -1 */
+static int
+use_bdl (JD, md)
+double JD;		/* julian date */
+MoonData md[NM];        /* fill md[1..NM-1].x/y/z for each moon */
+{
+#define	JUPRAU	.0004769108	/* jupiter radius, AU */
+	static FILE *fp;	/* keep open once find */
+	double x[NM], y[NM], z[NM];
+	char buf[1024];
+	int i;
+
+	/* only valid 1999 through 2010 */
+	if (JD < 2451179.50000 || JD >= 2455562.5)
+	    return (-1);
+
+	/* open first time */
+	if (!fp) {
+	    (void) sprintf (buf, "%s/auxil/jupiter.9910", getShareDir());
+	    fp = fopenh (buf, "r");
+	    if (!fp)
+		return (-1);
+	}
+
+	/* use it */
+	rewind (fp);
+	if ((i = read_bdl (fp, JD, x, y, z, buf)) < 0) {
+	    xe_msg (buf, 1);
+	    fclose (fp);
+	    fp = NULL;
+	    return (-1);
+	}
+	if (i != NM-1) {
+	    sprintf (buf, "BDL says %d moons, code expects %d", i, NM-1);
+	    xe_msg (buf, 1);
+	    fclose (fp);
+	    fp = NULL;
+	    return (-1);
+	}
+
+	/* copy into md[1..NM-1] with our scale and sign conventions */
+	for (i = 1; i < NM; i++) {
+	    md[i].x =  x[i-1]/JUPRAU;	/* we want jup radii +E */
+	    md[i].y = -y[i-1]/JUPRAU;	/* we want jup radii +S */
+	    md[i].z = -z[i-1]/JUPRAU;	/* we want jup radii +front */
+	}
+
+	/* ok */
+	return (0);
+}
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: jupmenu.c,v $ $Date: 1999/03/03 19:06:34 $ $Revision: 1.8 $ $Name:  $"};
