@@ -6,9 +6,12 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <math.h>
+#include <time.h>
+
 #if defined(__STDC__)
 #include <stdlib.h>
 #endif
+
 #include <X11/Xlib.h>
 #include <X11/keysym.h>
 #include <Xm/Xm.h>
@@ -95,8 +98,8 @@ typedef struct {
 
 
 static void create_main_form P_((Widget mainrc));
-static void make_prompts P_((Widget p_w, int pc, char *title, Field *fp,
-    int nfp));
+static void make_prompts P_((Widget p_w, int pc, char *title, char *tip,
+    Field *fp, int nfp));
 static void read_default_resources P_((void));
 static Widget fw P_((int fid));
 static void mm_new_now P_((void));
@@ -177,9 +180,9 @@ static int autotz = 0;		/* use tz_fromsys() each time step if this is
 static double DeltaT;		/* user's specific deltat, unless autodt is on*/
 static int autodt = 1;		/* compute delta if on, else use DeltaT. */
 
-/* strings used to command and prompt for turning autotz on and off */
-static char AutoOn[] = "Auto on";
-static char AutoOff[] = "Auto off";
+/* strings used to command and prompt for turning autotz and autodt on/off */
+static char auto_on[] = "Turn Auto on";
+static char auto_off[] = "Turn Auto off";
 
 static XtIntervalId mm_interval_id;	/* set while waiting in a pause loop */
 static int mm_selecting;        /* set while our fields are being selected */
@@ -194,8 +197,9 @@ static int mm_selecting;        /* set while our fields are being selected */
  */
 enum {
     JD_FID, UD_FID, UT_FID, LST_FID,TZN_FID, TZONE_FID, LD_FID, LT_FID, DT_FID,
-    DIP_FID, DAWN_FID, DUSK_FID, LON_FID, GAP, STPSZ_FID, NSTEP_FID, PAUSE_FID,
-    SITE_FID, LAT_FID, LONG_FID, ELEV_FID, TEMP_FID, PRES_FID, EPOCH_FID
+    DIP_FID, DAWN_FID, DUSK_FID, LON_FID, LSTM_FID, GAP, STPSZ_FID, NSTEP_FID,
+    PAUSE_FID, SITE_FID, LAT_FID, LONG_FID, ELEV_FID, TEMP_FID, PRES_FID,
+    EPOCH_FID
 };
 
 /* array of label/button pairs.
@@ -223,19 +227,19 @@ static Field mm_field_map[] = {
 	"Local sidereal time (h:m:s): ",		"Sidereal:", "LST"},
     {TZN_FID, "Local timezone name",
 	dummy,						"TZ Name:", NULL,
-	{    "Enter Timezone abbreviation (7 char max),\n\
-or select Auto On to track OS: ",
-	     "Enter Timezone abbreviation (7 char max),\n\
-or select Auto Off to turn off tracking: ",
+	{    "Enter a short fixed Timezone abbreviation,\n\
+or select `Turn Auto on' to choose automatically: ",
+	     "Enter a short fixed Timezone abbreviation,\n\
+or select `Turn Auto off' to freeze current setting: ",
 	     NULL
 	}
     },
     {TZONE_FID, "Local hours behind (west of) UTC",
 	dummy,						"TZ Offset:", "TZ",
-	{    "Enter Hours behind UTC (h:m:s),\n\
-or select Auto On to track OS: ",
-	     "Enter Hours behind UTC (h:m:s),\n\
-or select Auto Off to turn off tracking: ",
+	{    "Enter a fixed offset behind UTC (h:m:s), or\n\
+select `Turn Auto on' to choose automatically: ",
+	     "Enter a fixed offset behind UTC (h:m:s), or\n\
+select `Turn Auto off' to freeze current setting: ",
 	     NULL
 	}
     },
@@ -250,9 +254,10 @@ or select Auto Off to turn off tracking: ",
 	"Local time (h:m:s): ",				"Local Time:", "LT"},
     {DT_FID, "Terrestial Dynamical Time - Universal Time, seconds",
 	dummy,						"Delta T:", "DeltaT",
-	{  "Enter seconds TDT leads UTC,\nor Select Auto On to use model: ",
-	   "Enter seconds TDT leads UTC or Select Auto Off\n\
-(either way disables model): ",
+	{  "Enter a fixed offset TDT leads UTC (seconds),\n\
+or select `Turn Auto on' to use model: ",
+	   "Enter a fixed offset TDT leads UTC (seconds),\n\
+or select `Turn Auto off' to freeze current setting: ",
 	   NULL
 	}
     },
@@ -264,8 +269,10 @@ or select Auto Off to turn off tracking: ",
 	NULL,						"Dusk:", "Dusk"},
     {LON_FID, "Hours between dusk and dawn tonight",
 	NULL,				    		"Length:", "NiteLen"},
+    {LSTM_FID, "Local Sidereal Time at next local Midnight",
+	NULL,					        "LST@0:","MidnightLST"},
     {GAP},
-    {STPSZ_FID,	"Hours or method to advance time on next Update",
+    {STPSZ_FID,	"Period or event to advance time on next Update",
 	"\
 Select one of the above shortcuts\n\
 or enter any time step as follows:\n\
@@ -320,9 +327,9 @@ static Widget ext_w;
 static char *keywords[] = {
     /*  0 */	"TZone",	/* this is first so others may use */
     /*  1 */	"Epoch",
-    /*  2 */	"Elevation",
-    /*  3 */	"JD",
-    /*  4 */	"Sitename",
+    /*  2 */	"JD",
+    /*  3 */	"Sitename",
+    /*  4 */	"Elevation",
     /*  5 */	"Lat",
     /*  6 */	"Long",
     /*  7 */	"NSteps",
@@ -356,21 +363,22 @@ typedef struct {
     char *title;	/* name of this step option as a string */
     StepCode stepcode;	/* one of the StepCodes enum codes */
     double inc;		/* if code is FIXED_SS: fixed time step, in hours */
+    char *tip;		/* quick tip */
 } StepOption;
 /* N.B. leave RT Clock first!! see the RTC_SS_OPTION macro */
 static StepOption step_options[] = {
-    {"RT Clock",	RTC_SS},
-    {"24:00:00",	FIXED_SS,	24.0},
-    {"1:00:00",		FIXED_SS,	1.0},
-    {"0:01:00",		FIXED_SS,	1./60.},
-    {"Next Dawn",	NEXTDAWN_SS},
-    {"Next Dusk",	NEXTDUSK_SS},
-    {"Next Sun rise",	NEXTSUNRISE_SS},
-    {"Next Sun set",	NEXTSUNSET_SS},
-    {"Next Full moon",	NEXTFULLMOON_SS},
-    {"Next New moon",	NEXTNEWMOON_SS},
-    {"Sidereal Day",	FIXED_SS,	24.0 * SIDRATE},
-    {"Sidereal Month",	FIXED_SS,	27.3215 * 24.0},
+    {"RT Clock",	RTC_SS,		 0.0,	"Track computer clock"},
+    {"24:00:00",	FIXED_SS,	24.0,	"Step by 1 day"},
+    {"1:00:00",		FIXED_SS,	1.0,	"Step by 1 hour"},
+    {"0:01:00",		FIXED_SS,	1./60.,	"Step by 1 minute"},
+    {"Dawn",		NEXTDAWN_SS,	 0.0,	"Step to next dawn"},
+    {"Dusk",		NEXTDUSK_SS,	 0.0,	"Step to next dusk"},
+    {"Sun rise",	NEXTSUNRISE_SS,	 0.0,	"Step to next sun rise"},
+    {"Sun set",		NEXTSUNSET_SS,	 0.0,	"Step to next sun set"},
+    {"Full moon",	NEXTFULLMOON_SS, 0.0,	"Step to next full moon"},
+    {"New moon",	NEXTNEWMOON_SS,	 0.0,	"Step to next new moon"},
+    {"Sidereal Day",	FIXED_SS,  24.*SIDRATE,	"Step by 1 Earth rotation"},
+    {"Sidereal Month",	FIXED_SS,  27.3215*24.,	"Step by 1 Lunar revolution"},
 };
 
 /* make a way to refer to the RT clock entry; needed in order to implement
@@ -506,22 +514,37 @@ int whether;	/* whether setting up for plotting or for not plotting */
  * N.B. we assume sname points to stable long-term memory.
  */
 void
-mm_setsite (slat, slng, selev, sname, update)
-double slat;
+mm_setsite (slat, slng, sp, update)
+double slat;	/* always use these, even if given sp */
 double slng;
-double selev;
-char *sname;
+Site *sp;	/* might be NULL */
 int update;
 {
 	/* update loc and evelation fields of Now */
 	lat = slat;
 	lng = slng;
-	elev = selev/ERAD;	/* m to earth radii */
+	elev = sp ? sp->si_elev/ERAD : 0;	/* m to earth radii */
 
 	/* also save the site name */
-	msitename = sname;	/* NULL is OK */
+	msitename = sp ? sp->si_name : NULL;	/* yes, NULL is OK */
 	sites_abbrev (msitename, absitename, MAXSITENL);
 
+	/* new timezone if desired */
+	if (autotz) {
+	    char buf[64];
+
+	    if (sp && sp->si_tzdefn[0] != '\0')
+		(void) sprintf (buf, "TZ=%s", sp->si_tzdefn);
+	    else {
+		int hr = ((((int)floor((raddeg(-slng)+7.5)/15))+24)%24);
+		if (hr > 12) hr -= 24;
+		(void) sprintf (buf, "TZ=XXX%d", hr);
+	    }
+	    putenv (buf);
+	    tzset();
+	    (void) tz_fromsys (&now);
+	}
+
 	if (update)
 	    redraw_screen(1);
 	else {
@@ -682,27 +705,20 @@ Widget mainrc;
 
 	/* make the status label */
 	n = 0;
-	XtSetArg (args[n], XmNalignment, XmALIGNMENT_BEGINNING); n++;
+	XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
 	status_w = XmCreateLabel (mrc_w, "Status", args, n);
+	wtip (status_w,
+		"Current overall XEphem run-status and what you may do now.");
 	XtManageChild (status_w);
 
-	/* make a separator widget */
-	n = 0;
-	sep_w = XmCreateSeparator (mrc_w, "HSep2", args, n);
-	XtManageChild (sep_w);
-
 	/* make the "NEW CIRCUMSTANCES" label */
 	n = 0;
 	XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
 	newcir_w = XmCreateLabel (mrc_w, "NewCir", args, n);
 	set_xmstring (newcir_w, XmNlabelString, " ");
 	XtManageChild(newcir_w);
-	wtip (newcir_w, "Flashes while some fields may be out of date, until Update");
-
-	/* make a separator widget */
-	n = 0;
-	sep_w = XmCreateSeparator (mrc_w, "HSep3", args, n);
-	XtManageChild (sep_w);
+	wtip (newcir_w,
+		"Flashes while some fields may be out of date, until Update");
 
 	/* make a form for the basic areas */
 
@@ -735,7 +751,9 @@ Widget mainrc;
 	    ulfr_w = XmCreateFrame (f_w, "ULFr", args, n);
 	    XtManageChild (ulfr_w);
 
-		make_prompts (ulfr_w, 60, "Local", &mm_field_map[17], NFM-17);
+		make_prompts (ulfr_w, 50, "Local",
+			"Controls to set up location and observing conditions",
+				&mm_field_map[18], NFM-18);
 
 	    /* make frame in lower right */
 
@@ -747,7 +765,9 @@ Widget mainrc;
 	    lrfr_w = XmCreateFrame (f_w, "LRFr", args, n);
 	    XtManageChild (lrfr_w);
 
-		make_prompts (lrfr_w, 40, "Night", &mm_field_map[9], 8);
+		make_prompts (lrfr_w, 50, "Night",
+		    "Information about dusk, dawn and other night time issues",
+			&mm_field_map[9], 9);
 
 	    /* make frame in lower left */
 
@@ -761,7 +781,9 @@ Widget mainrc;
 	    llfr_w = XmCreateFrame (f_w, "LLFr", args, n);
 	    XtManageChild (llfr_w);
 
-		make_prompts (llfr_w, 45, "Time", &mm_field_map[0], 9);
+		make_prompts (llfr_w, 45, "Time",
+			"Controls to set the time used for all computations",
+				&mm_field_map[0], 9);
 
 	/* make a separator widget */
 	n = 0;
@@ -781,10 +803,11 @@ Widget mainrc;
 
 /* build the given Fields in a column */
 static void
-make_prompts (p_w, pc, title, fp, nfp)
+make_prompts (p_w, pc, title, tip, fp, nfp)
 Widget p_w;	/* parent */
 int pc;
 char *title;
+char *tip;
 Field *fp;
 int nfp;
 {
@@ -806,6 +829,7 @@ int nfp;
 	XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
 	b_w = XmCreateLabel (f_w, "MTL", args, n);
 	set_xmstring (b_w, XmNlabelString, title);
+	wtip (b_w, tip);
 	XtManageChild (b_w);
 
 	for (lfp = fp + nfp; fp < lfp; fp++) {
@@ -829,6 +853,8 @@ int nfp;
 		XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
 		b_w = XmCreateLabel (f_w, "GL", args, n);
 		set_xmstring (b_w, XmNlabelString, "Looping");	/* hack! */
+		wtip (b_w,
+			"Controls to set up automatic time stepping behavior");
 		XtManageChild (b_w);
 		continue;
 	    }
@@ -1464,9 +1490,9 @@ char *buf;
 	switch (i) {
 	case 0:  (void) chg_fld (buf, &mm_field_map[TZONE_FID]); break;
 	case 1:  (void) chg_fld (buf, &mm_field_map[EPOCH_FID]); break;
-	case 2:  (void) chg_fld (buf, &mm_field_map[ELEV_FID]); break;
-	case 3:  (void) chg_fld (buf, &mm_field_map[JD_FID]); break;
-	case 4:  (void) chg_fld (buf, &mm_field_map[SITE_FID]); break;
+	case 2:  (void) chg_fld (buf, &mm_field_map[JD_FID]); break;
+	case 3:  (void) chg_fld (buf, &mm_field_map[SITE_FID]); break;
+	case 4:  (void) chg_fld (buf, &mm_field_map[ELEV_FID]); break;
 	case 5:  (void) chg_fld (buf, &mm_field_map[LAT_FID]); break;
 	case 6:  (void) chg_fld (buf, &mm_field_map[LONG_FID]); break;
 	case 7:  (void) chg_fld (buf, &mm_field_map[NSTEP_FID]); break;
@@ -1597,11 +1623,11 @@ Field *fp;
 	    break;
 
 	case DT_FID:
-	    if (strncmp (bp, AutoOn, strlen(AutoOn)) == 0) {
+	    if (strncmp (bp, auto_on, strlen(auto_on)) == 0) {
 		DeltaT = deltat(mjd);
 		autodt = 1;
 		new = 1;
-	    } else if (strncmp (bp, AutoOff, strlen(AutoOff)) == 0) {
+	    } else if (strncmp (bp, auto_off, strlen(auto_off)) == 0) {
 		autodt = 0;
 	    } else {
 		DeltaT = atod (bp);
@@ -1615,14 +1641,24 @@ Field *fp;
 		time_fromsys (&now);
 		autotz = 1;
 	    } else {
-		double lst, utc;
+		double lst, gst, utc;
+
+		/* read goal */
 		now_lst (&now, &lst);
-		rnd_second (&lst);	/* match display precision */
 		f_scansex (lst, bp, &lst);
-		lst -= radhr(lng); /* convert to gst */
-		range (&lst, 24.0);
-		gst_utc (mjd_day(mjd), lst, &utc);
+
+		/* compute new mjd based on basic transform */
+		gst = lst - radhr(lng); /* convert to gst */
+		range (&gst, 24.0);
+		gst_utc (mjd_day(mjd), gst, &utc);
 		mjd = mjd_day(mjd) + utc/24.0;
+
+		/* repeat to add apparent refinements within now_lst() */
+		now_lst (&now, &tmp);
+		tmp -= lst;
+		if (tmp < -12) tmp += 24;
+		if (tmp >  12) tmp -= 24;
+		mjd -= tmp*(SIDRATE/24.0);
 	    }
 	    set_t0 (&now);
 	    new = 1;
@@ -1630,15 +1666,10 @@ Field *fp;
 
 	case TZN_FID:
 	case TZONE_FID:
-	    if (strncmp (bp, AutoOn, strlen(AutoOn)) == 0) {
-		if (tz_fromsys (&now) < 0) {
-		    xe_msg ("Can not get timezone info from OS", 0);
-		    autotz = 0;
-		} else {
-		    autotz = 1;
-		    new = 1;
-		}
-	    } else if (strncmp (bp, AutoOff, strlen(AutoOff)) == 0) {
+	    if (strncmp (bp, auto_on, strlen(auto_on)) == 0) {
+		autotz = 1;
+		mm_setsite (lat, lng, NULL, 1);
+	    } else if (strncmp (bp, auto_off, strlen(auto_off)) == 0) {
 		autotz = 0;
 	    } else {
 		if (fp->id == TZN_FID)
@@ -1659,7 +1690,7 @@ Field *fp;
 		Site **sipp, *sip;
 		(void) sites_get_list (&sipp);
 		sip = sipp[pos];
-		mm_setsite(sip->si_lat,sip->si_lng,sip->si_elev,sip->si_name,0);
+		mm_setsite(sip->si_lat, sip->si_lng, sip, 0);
 		new = 1;
 	    } else {
 		char buf[1024];
@@ -1674,7 +1705,7 @@ Field *fp;
 	    rnd_second (&tmp);		/* match display precision */
 	    f_scansex (tmp, bp, &tmp);
 	    lng = degrad (-tmp); 	/* want <0 radians west */
-	    msitename = NULL;
+	    mm_setsite (lat, lng, NULL, 0);
 	    new = 1;
 	    break;
 
@@ -1683,7 +1714,7 @@ Field *fp;
 	    rnd_second (&tmp);		/* match display precision */
 	    f_scansex (tmp, bp, &tmp);
 	    lat = degrad (tmp);
-	    msitename = NULL;
+	    mm_setsite (lat, lng, NULL, 0);
 	    new = 1;
 	    break;
 
@@ -1875,8 +1906,7 @@ Field *fp;
 	switch (fp->id) {
 	case TZN_FID: case TZONE_FID:
 	    XtManageChild (aw);
-	    set_xmstring (prompt_w, XmNapplyLabelString,
-					    autotz ? AutoOff : AutoOn);
+	    set_xmstring(prompt_w,XmNapplyLabelString, autotz?auto_off:auto_on);
 	    break;
 	case JD_FID: case UD_FID:
 	case LD_FID: case LST_FID:
@@ -1892,8 +1922,7 @@ Field *fp;
 	    break;
 	case DT_FID:
 	    XtManageChild (aw);
-	    set_xmstring (prompt_w, XmNapplyLabelString,
-						    autodt ? AutoOff : AutoOn);
+	    set_xmstring(prompt_w,XmNapplyLabelString, autodt?auto_off:auto_on);
 	    break;
 	case UT_FID:
 	    XtManageChild (aw);
@@ -1995,6 +2024,7 @@ Widget *wp;
 	    w = XmCreatePushButton (*wp, "MMStepPB", args, n);
 	    set_xmstring (w, XmNlabelString, sop->title);
 	    XtAddCallback (w, XmNactivateCallback, mm_step_cb, (XtPointer)sop);
+	    wtip (w, sop->tip);
 	    XtManageChild (w);
 	}
 
@@ -2135,6 +2165,7 @@ int all;
 }
 
 /* display dawn/dusk/length-of-night times.
+ * sneak in LST at midnight too since it too changes daily.
  */
 /* ARGSUSED */
 static void
@@ -2143,6 +2174,7 @@ int force;
 {
 	static char nope[] = "-----";
 	double dusk, dawn;
+	Now midnight;
 	int status;
 	char buf[64];
 
@@ -2182,6 +2214,12 @@ int force;
 	(void) sprintf (buf, "%%g degs");
 #endif
 	f_double (fw(DIP_FID), buf, raddeg(dip));
+
+	/* LST at midnight tonight */
+	midnight = now;
+	midnight.n_mjd = mjd_day(mjd+1-tz/24.0) + tz/24.0;
+	now_lst (&midnight, &dusk);
+	f_time (fw(LSTM_FID), dusk);
 }
 
 static void
@@ -2262,7 +2300,7 @@ ext_create_w()
 	Arg args[20];
 	int n;
 
-	(void) sprintf (fname, "%s/external.txt", getXRes ("UserDir", "work"));
+	(void) sprintf (fname, "%s/external.txt", getXRes("PrivateDir","work"));
 
 	n = 0;
 	XtSetArg (args[n], XmNdefaultPosition, False);  n++;
@@ -2295,8 +2333,7 @@ ext_readnext()
 		/* update the new time/lat/long */
 		lat = rlat;
 		lng = -rlng; 	/* we want <0 radians west */
-		msitename = NULL;
-		mjd = rjd - MJD0;
+		mm_setsite (lat, lng, NULL, 0);
 		set_t0 (&now);
 		return (0);
 	    }
@@ -2366,3 +2403,6 @@ static char *hlp[] = {
 };
         hlp_dialog ("ExternalInput", hlp, XtNumber(hlp));
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: mainmenu.c,v $ $Date: 1999/02/23 22:09:18 $ $Revision: 1.8 $ $Name:  $"};
