@@ -738,7 +738,7 @@ XtPointer call;
 	    /* turn off gravity so we get expose events for either shrink or
 	     * expand.
 	     */
-	    static before;
+	    static int before;
 	    XExposeEvent *e = &c->event->xexpose;
 
 	    if (!before) {
@@ -1052,3 +1052,6 @@ AutoMag **ampp;
 	*ampp = amp;
 	return (namp);
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: skyfiltmenu.c,v $ $Date: 1998/07/12 02:33:52 $ $Revision: 1.2 $ $Name:  $"};
