@@ -6,6 +6,13 @@
 #include <ctype.h>
 #include <math.h>
 
+#include <fcntl.h>
+
+#include <signal.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <sys/wait.h>
+
 #if defined(__STDC__)
 #include <stdlib.h>
 #include <string.h>
@@ -16,9 +23,8 @@ extern void *malloc();
 #if defined(_POSIX_SOURCE)
 #include <unistd.h>
 #else
-extern int read();
-extern int write();
 extern int close();
+extern int unlink();
 #endif
 
 #if defined(VMS) && !defined(O_WRONLY)
@@ -61,6 +67,8 @@ extern XtAppContext xe_app;
 #define XtD XtDisplay(toplevel_w)
 extern Colormap xe_cm;
 
+extern char *expand_home P_((char *path));
+extern char *getShareDir P_((void));
 extern char *getXRes P_((char *name, char *def));
 extern char *syserrstr P_((void));
 extern int confirm P_((void));
@@ -72,7 +80,9 @@ extern int xy2RADec P_((FImage *fip, double x, double y, double *rap,
     double *decp));
 extern void get_something P_((Widget w, char *resource, XtArgVal value));
 extern void hlp_dialog P_((char *tag, char *deflt[], int ndeflt));
+extern void mm_newcaldate P_((double newmjd));
 extern void pm_set P_((int percentage));
+extern void pm_down P_((void));
 extern void pm_up P_((void));
 extern void prompt_map_cb P_((Widget w, XtPointer client, XtPointer call));
 extern void query P_((Widget tw, char *msg, char *label1, char *label2,
@@ -99,6 +109,7 @@ static void sf_create P_((void));
 static void sf_newLOHI P_((void));
 static void sf_newImage P_((void));
 static void initFSB P_((Widget w));
+static void initPubShared P_((Widget rc_w, Widget fsb_w));
 static void sf_stsci_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sf_eso_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sf_save_cb P_((Widget w, XtPointer client, XtPointer call));
@@ -111,6 +122,7 @@ static void sf_motion_eh P_((Widget w, XtPointer client, XEvent *ev,
     Boolean *dispatch));
 static void sf_gmlohi_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sf_wide_cb P_((Widget w, XtPointer client, XtPointer call));
+static void sf_setdate_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sf_narrow_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sf_gamma_cb P_((Widget w, XtPointer client, XtPointer call));
 static void sf_inv_cb P_((Widget w, XtPointer client, XtPointer call));
@@ -130,15 +142,20 @@ static int dsswcs P_((FImage *fip));
 static int dssxy2RADec P_((FImage *fip, double X, double Y, double *rap,
     double *decp));
 static int wcsok P_((FImage *fip));
+static int fitsObs P_((double *mjdp));
 static void newfim P_((FImage *fip));
+static int prepOpen P_((char fn[], char errmsg[]));
 
 static Widget sf_w;		/* main dialog */
+static Widget gunzip_w;		/* TB for whether to retrieve compressed */
 static Widget savefn_w;		/* TF for save filename */
 static Widget fsb_w;		/* FSB for opening a file */
 static Widget hdr_w;		/* ScrolledText for the FITS header */
 static Widget fda_w;		/* Drawing area for the contrast map */
 static Widget gamma_w;		/* gamma scale */
 static Widget autoname_w;	/* TB for whether to auto set save filename */ 
+static Widget obsdate_w;	/* label for obs date string */
+static Widget setobsdate_w;	/* PB to set main to obs date */
 
 static FImage fim;		/* current FITS image */
 static Pixmap fpm;		/* current pixmap with image */
@@ -160,7 +177,7 @@ static char mxr[] = "FITSMapColor";	/* X resource name of colormap color */
 #define	MMH	10		/* map marker height */
 #define	MMW	5		/* map marker half-width */
 
-static char fitsd[] = "UserDir";	/* resource name of FITS working dir */
+static char fitsd[] = "PrivateDir";	/* resource name of FITS working dir */
 static char fitsp[] = "FITSpattern";	/* resource name of FITS file pattern */
 
 static XImage *glass_xim;       /* glass XImage -- 0 means new or can't */
@@ -576,6 +593,51 @@ int wx, wy;	/* window coords of cursor */
 	}
 }
 
+/* t00fri: include possibility to read .fth compressed files */
+static int
+prepOpen (fn, errmsg)
+char fn[];
+char errmsg[];
+{
+	int fd;
+	int l;
+
+	l = strlen (fn);
+	if (l < 4 || strcmp(fn+l-4, ".fth")) {
+	    /* just open directly */
+	    fd = openh (fn, O_RDONLY);
+	    if (fd < 0)
+		strcpy (errmsg, syserrstr());
+	} else {
+	    /* ends with .fth so need to run through fdecompress
+	     * TODO: this is a really lazy way to do it --
+	     */
+	    char cmd[2048];
+	    char tmp[128];
+	    int s;
+
+	    tmpnam (tmp);
+	    strcat (tmp, ".fth");
+	    sprintf (cmd, "cp %s %s; fdecompress -r %s", fn, tmp, tmp);
+	    s = system (cmd);
+	    if (s != 0) {
+		sprintf (errmsg, "Can not execute `%s' ", cmd);
+		if (s < 0)
+		    strcat (errmsg, syserrstr());
+		fd = -1;
+	    } else {
+		tmp[strlen(tmp)-1] = 's';
+		fd = openh (tmp, O_RDONLY);
+		(void) unlink (tmp);	/* once open, remove the .fts copy */
+		if (fd < 0)
+		    sprintf (errmsg, "Can not decompress %s: %s", tmp,
+							    syserrstr());
+	    }
+	}
+
+	return (fd);
+}
+
 /* attempt to open a FITS file. also insure it has WCS and other fields.
  * if all ok, fill in fim and return 0, else return -1.
  */
@@ -586,6 +648,7 @@ char *name;
 	char buf[1024];
 	FImage sfim, *fip = &sfim;
 	double eq;
+	char errmsg[1024];
 	int fd;
 	int s;
 
@@ -593,9 +656,9 @@ char *name;
 	initFImage (fip);
 
 	/* open the fits file */
-	fd = openh (name, O_RDONLY);
+	fd = prepOpen (name, errmsg);
 	if (fd < 0) {
-	    (void) sprintf (buf, "%s: %s", name, syserrstr());
+	    (void) sprintf (buf, "%s: %s", name, errmsg);
 	    xe_msg (buf, 1);
 	    return(-1);
 	}
@@ -632,9 +695,6 @@ char *name;
 		resetFImage (fip);
 		return (-1);
 	    } else {
-		(void) sprintf(buf,"%s: allowing EPOCH but EQUINOX is standard",
-									name);
-		xe_msg (buf, 1);
 		setRealFITS (fip, "EQUINOX", eq, 10, "Copied from EPOCH");
 	    }
 	}
@@ -666,10 +726,11 @@ static void
 sf_create()
 {
 	Widget tf_w, bf_w;
-	Widget heq_w, g_w, rb_w;
+	Widget heq_w, g_w, rc_w, rb_w;
 	Widget inv_w;
 	Widget p_w, fr_w;
 	Widget n_w, w_w;
+	Widget h_w;
 	Widget w;
 	int h, g;
 	char fn[1024];
@@ -709,7 +770,7 @@ sf_create()
 	/* the top form */
 
 	n = 0;
-	XtSetArg (args[n], XmNverticalSpacing, 10); n++;
+	XtSetArg (args[n], XmNfractionBase, 16); n++;
 	tf_w = XmCreateForm (p_w, "TF", args, n);
 	XtManageChild (tf_w);
 
@@ -717,21 +778,23 @@ sf_create()
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
+	    XtSetArg (args[n], XmNtopOffset, 6); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_BEGINNING); n++;
 	    n_w = XmCreateLabel (tf_w, "Lab", args, n);
 	    set_xmstring (n_w, XmNlabelString,
-				"Retrieve Digitized Sky Survey Image from ..");
+				"Retrieve Digitized Sky Survey Image from ...");
 	    XtManageChild (n_w);
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNtopWidget, n_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 2); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_POSITION); n++;
-	    XtSetArg (args[n], XmNleftPosition, 15); n++;
+	    XtSetArg (args[n], XmNleftPosition, 1); n++;
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_POSITION); n++;
-	    XtSetArg (args[n], XmNrightPosition, 45); n++;
+	    XtSetArg (args[n], XmNrightPosition, 5); n++;
 	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
 	    w = XmCreatePushButton (tf_w, "STScI", args, n);
 	    XtAddCallback (w, XmNactivateCallback, sf_stsci_cb, NULL);
@@ -742,10 +805,11 @@ sf_create()
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNtopWidget, n_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 2); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_POSITION); n++;
-	    XtSetArg (args[n], XmNleftPosition, 55); n++;
+	    XtSetArg (args[n], XmNleftPosition, 6); n++;
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_POSITION); n++;
-	    XtSetArg (args[n], XmNrightPosition, 85); n++;
+	    XtSetArg (args[n], XmNrightPosition, 10); n++;
 	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
 	    w = XmCreatePushButton (tf_w, "ESO", args, n);
 	    wtip (w, "Retrieve DSS image from ESO");
@@ -753,20 +817,65 @@ sf_create()
 	    set_xmstring (w, XmNlabelString, "ESO");
 	    XtManageChild (w);
 
+	    n = 0;
+	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	    XtSetArg (args[n], XmNtopWidget, n_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 2); n++;
+	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_POSITION); n++;
+	    XtSetArg (args[n], XmNleftPosition, 11); n++;
+	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_POSITION); n++;
+	    XtSetArg (args[n], XmNrightPosition, 15); n++;
+	    XtSetArg (args[n], XmNindicatorType, XmN_OF_MANY); n++;
+	    XtSetArg (args[n], XmNindicatorOn, True); n++;
+	    gunzip_w = XmCreateToggleButton (tf_w, "UseGzip", args, n);
+	    wtip(gunzip_w,"Retrieve compressed then uncompress using `gunzip'");
+	    set_xmstring (gunzip_w, XmNlabelString, "compressed");
+	    XtManageChild (gunzip_w);
+
+	    /* header, with possible date */
+
+	    n = 0;
+	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	    XtSetArg (args[n], XmNtopWidget, gunzip_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 18); n++;
+	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_BEGINNING); n++;
+	    h_w = XmCreateLabel (tf_w, "Lab", args, n);
+	    set_xmstring (h_w, XmNlabelString, "FITS Header:");
+	    XtManageChild (h_w);
+
+	    n = 0;
+	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	    XtSetArg (args[n], XmNtopWidget, gunzip_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 16); n++;
+	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	    setobsdate_w = XmCreatePushButton (tf_w, "SO", args, n);
+	    set_xmstring (setobsdate_w, XmNlabelString, "Set main");
+	    XtAddCallback (setobsdate_w, XmNactivateCallback, sf_setdate_cb, 0);
+	    wtip(setobsdate_w,"Set main XEphem time to this Observation time");
+	    XtManageChild (setobsdate_w);
+	    XtSetSensitive (setobsdate_w, False); /* set true when have date */
+
+	    n = 0;
+	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	    XtSetArg (args[n], XmNtopWidget, gunzip_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 18); n++;
+	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
+	    XtSetArg (args[n], XmNleftWidget, h_w); n++;
+	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
+	    XtSetArg (args[n], XmNrightWidget, setobsdate_w); n++;
+	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
+	    obsdate_w = XmCreateLabel (tf_w, "ObsDate", args, n);
+	    set_xmstring (obsdate_w, XmNlabelString, " ");
+	    wtip(obsdate_w, "Best-guess of time of Observation");
+	    XtManageChild (obsdate_w);
+
 	    /* scrolled text in which to display the header */
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
-	    XtSetArg (args[n], XmNtopWidget, w); n++;
-	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
-	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_BEGINNING); n++;
-	    w = XmCreateLabel (tf_w, "Lab", args, n);
-	    set_xmstring (w, XmNlabelString, "FITS Header:");
-	    XtManageChild (w);
-
-	    n = 0;
-	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
-	    XtSetArg (args[n], XmNtopWidget, w); n++;
+	    XtSetArg (args[n], XmNtopWidget, setobsdate_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 2); n++;
 	    XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNbottomOffset, 10); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
@@ -782,7 +891,6 @@ sf_create()
 	/* the bottom form */
 
 	n = 0;
-	XtSetArg (args[n], XmNverticalSpacing, 10); n++;
 	bf_w = XmCreateForm (p_w, "BF", args, n);
 	XtManageChild (bf_w);
 
@@ -790,7 +898,7 @@ sf_create()
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
-	    XtSetArg (args[n], XmNtopOffset, 10); n++;
+	    XtSetArg (args[n], XmNtopOffset, 16); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
 	    w = XmCreateLabel (bf_w, "GML", args, n);
 	    set_xmstring (w, XmNlabelString, "Gray scale:");
@@ -798,7 +906,7 @@ sf_create()
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
-	    XtSetArg (args[n], XmNtopOffset, 10); n++;
+	    XtSetArg (args[n], XmNtopOffset, 16); n++;
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
 	    n_w = XmCreatePushButton (bf_w, "Narrow", args, n);
 	    XtAddCallback (n_w, XmNactivateCallback, sf_narrow_cb, 0);
@@ -807,7 +915,7 @@ sf_create()
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
-	    XtSetArg (args[n], XmNtopOffset, 10); n++;
+	    XtSetArg (args[n], XmNtopOffset, 16); n++;
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNrightWidget, n_w); n++;
 	    XtSetArg (args[n], XmNrightOffset, 15); n++;
@@ -818,7 +926,7 @@ sf_create()
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
-	    XtSetArg (args[n], XmNtopOffset, 10); n++;
+	    XtSetArg (args[n], XmNtopOffset, 16); n++;
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNrightWidget, w_w); n++;
 	    XtSetArg (args[n], XmNrightOffset, 15); n++;
@@ -834,10 +942,9 @@ sf_create()
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNtopWidget, n_w); n++;
-	    XtSetArg (args[n], XmNtopOffset, 15); n++;
+	    XtSetArg (args[n], XmNtopOffset, 14); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNorientation, XmHORIZONTAL); n++;
-	    XtSetArg (args[n], XmNspacing, 10); n++;
 	    rb_w = XmCreateRadioBox (bf_w, "GrayMethod", args, n);
 	    XtManageChild (rb_w);
 
@@ -876,12 +983,13 @@ sf_create()
 	    /* gamma scale between rb and right edge */
 
 	    n = 0;
-	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
-	    XtSetArg (args[n], XmNleftWidget, rb_w); n++;
-	    XtSetArg (args[n], XmNleftOffset, 15); n++;
-	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNtopWidget, n_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 6); n++;
+	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
+	    XtSetArg (args[n], XmNleftWidget, rb_w); n++;
+	    XtSetArg (args[n], XmNleftOffset, 6); n++;
+	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNorientation, XmHORIZONTAL); n++;
 	    XtSetArg (args[n], XmNminimum, (int)(1./GAM_MAX*100)); n++;
 	    XtSetArg (args[n], XmNmaximum, (int)(GAM_MAX*100)); n++;
@@ -901,6 +1009,7 @@ sf_create()
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNtopWidget, gamma_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 6); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
 	    fr_w = XmCreateFrame (bf_w, "HF", args, n);
@@ -921,6 +1030,7 @@ sf_create()
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNtopWidget, fr_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 16); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
 	    w = XmCreateLabel (bf_w, "Save", args, n);
 	    set_xmstring (w, XmNlabelString, "Save as FITS file:");
@@ -929,6 +1039,7 @@ sf_create()
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNtopWidget, fr_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 16); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_POSITION); n++;
 	    XtSetArg (args[n], XmNleftPosition, 45); n++;
 	    w = XmCreatePushButton (bf_w, "Save", args, n);
@@ -939,6 +1050,7 @@ sf_create()
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNtopWidget, fr_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 16); n++;
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
 	    autoname_w = XmCreateToggleButton (bf_w, "AutoName", args, n);
 	    set_xmstring (autoname_w, XmNlabelString, "Auto name");
@@ -949,6 +1061,7 @@ sf_create()
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNtopWidget, autoname_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 6); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNvalue, fn); n++;
@@ -962,8 +1075,8 @@ sf_create()
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
 	    XtSetArg (args[n], XmNtopWidget, savefn_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 16); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
-	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_BEGINNING); n++;
 	    w = XmCreateLabel (bf_w, "Lab", args, n);
 	    set_xmstring (w, XmNlabelString, "Open a FITS file:");
@@ -971,13 +1084,26 @@ sf_create()
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
-	    XtSetArg (args[n], XmNtopWidget, w); n++;
+	    XtSetArg (args[n], XmNtopWidget, savefn_w); n++;
+	    XtSetArg (args[n], XmNtopOffset, 16); n++;
+	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	    XtSetArg (args[n], XmNorientation, XmHORIZONTAL); n++;
+	    XtSetArg (args[n], XmNspacing, 5); n++;
+	    rc_w = XmCreateRowColumn (bf_w, "USRB", args, n);
+	    XtManageChild (rc_w);
+
+	    n = 0;
+	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+	    XtSetArg (args[n], XmNtopWidget, rc_w); n++;
 	    XtSetArg (args[n], XmNbottomAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	    /* t00fri: keeps FILE scrolled list width correct */
+            XtSetArg (args[n], XmNresizePolicy, XmRESIZE_NONE); n++;
 	    fsb_w = XmCreateFileSelectionBox (bf_w, "FSB", args, n);
 	    XtManageChild (fsb_w);
 	    initFSB(fsb_w);
+	    initPubShared (rc_w, fsb_w);
 }
 
 /* init the directory and pattern resources of the given FileSelectionBox.
@@ -990,8 +1116,8 @@ Widget fsb_w;
 	Widget w;
 
 	/* set default dir and pattern */
-	set_xmstring (fsb_w, XmNdirectory, getXRes (fitsd, "fts"));
-	set_xmstring (fsb_w, XmNpattern, getXRes (fitsp, "f*ts"));
+	set_xmstring (fsb_w, XmNdirectory, expand_home(getXRes (fitsd, "fts")));
+	set_xmstring (fsb_w, XmNpattern, getXRes (fitsp, "*.f*t[sh]"));
 
 	/* change some button labels.
 	 * N.B. can't add tips because these are really Gadgets.
@@ -1017,6 +1143,64 @@ Widget fsb_w;
 	XtAddCallback (fsb_w, XmNhelpCallback, sf_help_cb, NULL);
 }
 
+/* callback from the Public dir PB */
+/* ARGSUSED */
+static void
+sharedDirCB (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	Widget fsb_w = (Widget)client;
+	char buf[1024];
+
+	(void) sprintf (buf, "%s/fits", getShareDir());
+	set_xmstring (fsb_w, XmNdirectory, expand_home(buf));
+}
+
+/* callback from the Private dir PB */
+/* ARGSUSED */
+static void
+privateDirCB (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	Widget fsb_w = (Widget)client;
+
+	set_xmstring (fsb_w, XmNdirectory,
+				    expand_home(getXRes("PrivateDir", "work")));
+}
+
+/* build a set of PB in RC rc_w so that they
+ * set the XmNdirectory resource in the FSB fsb_w and invoke the Filter.
+ */
+static void
+initPubShared (rc_w, fsb_w)
+Widget rc_w, fsb_w;
+{
+	Arg args[20];
+	Widget w;
+	int n;
+
+	n = 0;
+	w = XmCreateLabel (rc_w, "Dir", args, n);
+	set_xmstring (w, XmNlabelString, "Go to:");
+	XtManageChild (w);
+
+	n = 0;
+	w = XmCreatePushButton (rc_w, "Private", args, n);
+	XtAddCallback(w, XmNactivateCallback, privateDirCB, (XtPointer)fsb_w);
+	wtip (w,"Set Filter directory to value of XEphem.PrivateDir resource");
+	XtManageChild (w);
+
+	n = 0;
+	w = XmCreatePushButton (rc_w, "Shared", args, n);
+	XtAddCallback(w, XmNactivateCallback, sharedDirCB, (XtPointer)fsb_w);
+	wtip (w, "Set Filter directory to XEphem.ShareDir/fits");
+	XtManageChild (w);
+}
+
 /* called when STScI is hit */
 /* ARGSUSED */
 static void
@@ -1286,7 +1470,7 @@ XtPointer call;
 
 	switch (c->reason) {
 	case XmCR_EXPOSE: {
-	    static before;
+	    static int before;
 	    XExposeEvent *e = &c->event->xexpose;
 
 	    if (!before) {
@@ -1367,6 +1551,20 @@ XtPointer call;
 	sv_newfits();
 }
 
+/* callback to set main time to match FITS */
+/* ARGSUSED */
+static void
+sf_setdate_cb (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	double newmjd;
+
+	if (fitsObs(&newmjd) == 0)
+	    mm_newcaldate(newmjd);
+}
+
 /* callback to narrow the gray scale */
 /* ARGSUSED */
 static void
@@ -1487,7 +1685,7 @@ sf_drawHistogram()
 
 	/* draw the histogram all across each x of the window */
 	XSetForeground (dsp, gc, hp);
-	for (np = x = 0; x < wid; x++) {
+	for (np = x = 0; x < (int)wid; x++) {
 	    int i, p, y;
 	    int l, h;
 
@@ -1771,6 +1969,60 @@ char buf[];
 	return (-1);
 }
 
+/* return 1 if want to use gunzip, else 0 */
+static int
+use_gunzip()
+{
+	return (XmToggleButtonGetState (gunzip_w));
+}
+
+/* setup the pipe between gunzip and xephem to decompress the data.
+ * return pid if ok, else -1.
+ */
+static int
+setup_gunzip_pipe(int sockfd)
+{
+	int gzfd[2];		/* file descriptors for gunzip pipe */
+	int pid;
+
+	/* make the pipe to gunzip */
+	if (pipe(gzfd) < 0) {
+	    xe_msg ("Can not make pipe to gunzip", 0);
+	    return (-1);
+	}
+
+	/* no zombies */
+	signal (SIGCHLD, SIG_IGN);
+  
+	/* fork/exec gunzip */
+	switch((pid = fork())) {
+	case 0:			/* child: put gunzip between socket and us */
+	    close (gzfd[0]);	/* do not need read side of pipe */
+	    dup2 (sockfd, 0);	/* socket becomes gunzip's stdin */
+	    close (sockfd);	/* do not need after dup */
+	    dup2 (gzfd[1], 1);	/* write side of pipe becomes gunzip's stdout */
+	    close (gzfd[1]);	/* do not need after dup */
+	    execlp ("gunzip", "gunzip", "-c", NULL);
+	    exit (1);		/* exit in case gunzip disappeared */
+	    break;
+
+	case -1:	/* fork failed */
+	    xe_msg ("gunzip fork failed", 0);
+	    return (-1);
+
+	default:	/* parent */
+	    break;
+	}
+	
+	/* put gunzip between the socket and us */
+	close (gzfd[1]);	/* do not need write side of pipe */
+	dup2 (gzfd[0], sockfd);	/* read side of pipe masquarades as socket */
+	close (gzfd[0]);	/* do not need after dup */
+
+	/* return gunzip's pid */
+	return (pid);
+}
+
 /* start an input stream reading a FITS image from ESO */
 static void
 eso_fits()
@@ -1780,11 +2032,12 @@ eso_fits()
 	double fov, alt, az, ra, dec;
 	char rastr[32], *rap, decstr[32], *decp;
 	char buf[1024], msg[1024];
+	int gzpid;
 	int sockfd;
 	int aamode;
 	int sawfits;
 
-	/* don't turn off watch until completely finished */
+	/* do not turn off watch until completely finished */
 	watch_cursor (1);
 
 	/* let user abort */
@@ -1813,8 +2066,13 @@ eso_fits()
 	fs_sexa (decstr, dec, 3, 3600);
 	for (decp = decstr; *decp == ' '; decp++)
 	    continue;
-	(void) sprintf (buf, "/dss/dss?ra=%s&dec=%s&mime-type=application/x-fits&x=%.0f&y=%.0f HTTP/1.0\nUser-Agent: xephem/%s\n\n",
-					    rap, decp, fov, fov, PATCHLEVEL);
+	(void) sprintf (buf, "/dss/dss?ra=%s&dec=%s&mime-type=%s&x=%.0f&y=%.0f HTTP/1.0\nUser-Agent: xephem/%s\n\n",
+						rap, decp,
+			use_gunzip() ? "display/gz-fits" : "application/x-fits",
+						fov, fov, PATCHLEVEL);
+	(void) sprintf (msg, "Command to %s:", host);
+	xe_msg (msg, 0);
+	xe_msg (buf, 0);
 	sockfd = httpGET (host, buf, msg);
 	if (sockfd < 0) {
 	    xe_msg (msg, 1);
@@ -1831,7 +2089,7 @@ eso_fits()
 		sawfits = 1;
 	}
 
-	/* if don't see a fits file, show what we do find */
+	/* if do not see a fits file, show what we do find */
 	if (!sawfits) {
 	    xe_msg (" ", 0);
 	    xe_msg ("Network message follows:", 0);
@@ -1848,12 +2106,27 @@ eso_fits()
 	    return;
 	}
 
+	/* possibly connect via gunzip -- weird if have gunzip but can't */
+	if (use_gunzip()) {
+	    gzpid = setup_gunzip_pipe(sockfd);
+	    if (gzpid < 0) {
+		watch_cursor (0);
+		close (sockfd);
+		stopd_down();
+		return;
+	    }
+	} else
+	    gzpid = -1;
+		
+
 	/* read the FITS header portion */
 	if (readFITSHeader (sockfd, fip, buf) < 0) {
 	    watch_cursor (0);
 	    xe_msg (buf, 1);
 	    resetFImage (fip);
 	    close (sockfd);
+	    if (gzpid > 0)
+		kill (gzpid, SIGTERM);
 	    stopd_down();
 	    return;
 	}
@@ -1863,6 +2136,8 @@ eso_fits()
 	    watch_cursor (0);
 	    resetFImage (fip);
 	    close (sockfd);
+	    if (gzpid > 0)
+		kill (gzpid, SIGTERM);
 	    stopd_down();
 	    return;
 	}
@@ -1881,11 +2156,12 @@ stsci_fits()
 	static FImage sfim, *fip = &sfim;
 	double fov, alt, az, ra, dec;
 	char buf[1024], msg[1024];
+	int gzpid;
 	int sockfd;
 	int aamode;
 	int sawfits;
 
-	/* don't turn off watch until completely finished */
+	/* do not turn off watch until completely finished */
 	watch_cursor (1);
 
 	/* let user abort */
@@ -1906,8 +2182,13 @@ stsci_fits()
 	    fov = MINDSSFOV;
 
 	/* format and send the request */
-	(void) sprintf (buf, "/cgi-bin/dss_search?ra=%.5f&dec=%.5f&equinox=J2000&height=%.0f&width=%.0f&format=FITS&compression=NONE&version=3 HTTP/1.0\nUser-Agent: xephem/%s\n\n",
-						ra, dec, fov, fov, PATCHLEVEL);
+	(void) sprintf(buf,"/cgi-bin/dss_search?ra=%.5f&dec=%.5f&equinox=J2000&height=%.0f&width=%.0f&format=FITS&compression=%s&version=3 HTTP/1.0\nUser-Agent: xephem/%s\n\n",
+						ra, dec, fov, fov,
+						use_gunzip() ? "gz" : "NONE",
+						PATCHLEVEL);
+	(void) sprintf (msg, "Command to %s:", host);
+	xe_msg (msg, 0);
+	xe_msg (buf, 0);
 	sockfd = httpGET (host, buf, msg);
 	if (sockfd < 0) {
 	    xe_msg (msg, 1);
@@ -1923,29 +2204,44 @@ stsci_fits()
 		sawfits = 1;
 	}
 
-	/* if don't see a fits file, show what we do find */
+	/* if do not see a fits file, show what we do find */
 	if (!sawfits) {
 	    xe_msg (" ", 0);
 	    xe_msg ("Network message follows:", 0);
 	    xe_msg (" ", 0);
 	    while (recvline (sockfd, buf, sizeof(buf)) > 0)
 		xe_msg (buf, 0);
-	    xe_msg ("Error -- see Main->File->Messages", 1);
 	    xe_msg (" ", 0);
 	    xe_msg ("End of Network message", 0);
 	    xe_msg (" ", 0);
+	    xe_msg ("Error -- see Main->File->Messages", 1);
 	    watch_cursor (0);
 	    close (sockfd);
 	    stopd_down();
 	    return;
 	}
 
+
+	/* possibly connect via gunzip -- weird if have gunzip but can't */
+	if (use_gunzip()) {
+	    gzpid = setup_gunzip_pipe(sockfd);
+	    if (gzpid < 0) {
+		watch_cursor (0);
+		close (sockfd);
+		stopd_down();
+		return;
+	    }
+	} else
+	    gzpid = -1;
+
 	/* read the FITS header portion */
 	if (readFITSHeader (sockfd, fip, buf) < 0) {
 	    watch_cursor (0);
 	    xe_msg (buf, 1);
 	    resetFImage (fip);
 	    close (sockfd);
+	    if (gzpid > 0)
+		kill (gzpid, SIGTERM);
 	    stopd_down();
 	    return;
 	}
@@ -1955,6 +2251,8 @@ stsci_fits()
 	    watch_cursor (0);
 	    resetFImage (fip);
 	    close (sockfd);
+	    if (gzpid > 0)
+		kill (gzpid, SIGTERM);
 	    stopd_down();
 	    return;
 	}
@@ -1979,13 +2277,14 @@ XtInputId *id;
 
 	/* read another chunk */
 	if (readIncFITS (sockfd, fip, buf) < 0) {
-	    watch_cursor (0);
 	    xe_msg (buf, 1);
 	    resetFImage (fip);
 	    close (sockfd);
 	    XtRemoveInput (readId);
 	    readId = (XtInputId)0;
 	    stopd_down();
+	    pm_down();
+	    watch_cursor (0);
 	    return;
 	}
 
@@ -2001,6 +2300,7 @@ XtInputId *id;
 
 	/* finished reading */
 	stopd_down();
+	pm_down();
 	close (sockfd);
 	XtRemoveInput (readId);
 	readId = (XtInputId)0;
@@ -2044,15 +2344,46 @@ XtInputId *id;
 }
 
 /* install fip as the new fim.
- * N.B. malloced fields in fip are just re-used, so don't reset it on return.
+ * N.B. malloced fields in fip are just re-used, so do not reset it on return.
  */
 static void
 newfim (fip)
 FImage *fip;
 {
+	double objsmjd;
+
 	resetFImage (&fim);
 	(void) memcpy ((void *)&fim, (void *)fip, sizeof(fim));
 	fimok = 1;
+
+	if (fitsObs(&objsmjd) == 0) {
+	    int mm, yy, d, h, m, s;
+	    double dd, dh, dm, ds;
+	    char buf[128];
+
+	    mjd_cal (objsmjd, &mm, &dd, &yy);
+	    d = (int)dd;
+	    dh = (dd - d)*24.;
+	    h = (int)dh;
+	    dm = (dh - h)*60.;
+	    m = (int)dm;
+	    ds = (dm - m)*60.;
+	    if (ds > 59.5) {
+		s = 0;
+		if (++m == 60) {
+		    m = 0;
+		    h += 1; /* TODO: roll date if hits 24 */
+		}
+	    } else
+		s = (int)ds;
+
+	    sprintf (buf, "%d-%d-%d %02d:%02d:%02d", yy, mm, d, h, m, s);
+	    set_xmstring (obsdate_w, XmNlabelString, buf);
+	    XtSetSensitive (setobsdate_w, True);
+	} else {
+	    set_xmstring (obsdate_w, XmNlabelString, " ");
+	    XtSetSensitive (setobsdate_w, False);
+	}
 }
 
 /* check for the WCS headers.
@@ -2223,3 +2554,47 @@ double *rap, *decp;
 
 	return (0);
 }
+
+/* poke around in the headers and try to find the mjd of the observation.
+ * return 0 if think we found something, else -1
+ */
+static int
+fitsObs(mjdp)
+double *mjdp;
+{
+	FImage *fip = sf_getFImage();
+	int mm, dd, yy;
+	char buf[128];
+	double mjd0;
+
+	if (!fip)
+	    return (-1);
+
+	if (getRealFITS (fip, "JD", &mjd0) == 0) {
+	    *mjdp = mjd0 - MJD0;
+	    return (0);
+	}
+
+	if (getStringFITS (fip, "DATE-OBS", buf) == 0
+			&& sscanf (buf, "%d/%d/%d", &dd, &mm, &yy) == 3) {
+	    if (yy < 20)
+		yy += 1000;	/* TODO: Y2K! */
+	    cal_mjd (mm, (double)dd, yy+1900, &mjd0);
+	    if (getStringFITS (fip, "UT", buf) == 0 
+			    || getStringFITS (fip, "TIME-OBS", buf) == 0) {
+		int h, m;
+		double s;
+		if (sscanf (buf, "%d:%d:%lf", &h, &m, &s) == 3) {
+		    *mjdp = mjd0 + (s/3600. + m/60. + h)/24.0;
+		    return (0);
+		}
+	    }
+	    *mjdp = mjd0;
+	    return (0);	/* better than nothing I suppose */
+	}
+
+	return (-1);
+}
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: skyfits.c,v $ $Date: 1999/03/14 05:06:00 $ $Revision: 1.8 $ $Name:  $"};
