@@ -89,7 +89,7 @@ sv_create_list_w()
 	Arg args[20];
 	int n;
 
-	(void) sprintf (fname, "%s/skylist.txt", getXRes ("UserDir", "work"));
+	(void) sprintf (fname, "%s/skylist.txt", getXRes("PrivateDir","work"));
 
 	n = 0;
 	XtSetArg (args[n], XmNcolormap, xe_cm); n++;
@@ -274,7 +274,10 @@ FILE *fp;
 	    else
 		(void) fprintf (fp, "   ");
 
-	    (void) fprintf (fp, " %5d", op->s_size);
+	    if (op->s_size < 999.5)
+		(void) fprintf (fp, "%5.1f", op->s_size);
+	    else
+		(void) fprintf (fp, "%5.0f", op->s_size);
 
 	    (void) fprintf (fp, " %s", obj_description (op));
 
@@ -694,3 +697,6 @@ se_rmall()
 	}
 	neyep = 0;
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: skylist.c,v $ $Date: 1999/02/15 23:21:12 $ $Revision: 1.2 $ $Name:  $"};
