@@ -52,8 +52,8 @@ extern void wtip P_((Widget w, char *string));
 extern void xe_msg P_((char *msg, int app_modal));
 
 static void srch_create_form P_((void));
-static srch_isup P_((void));
-static srching_now P_((void));
+static int srch_isup P_((void));
+static int srching_now P_((void));
 static void srch_set_buttons P_((int whether));
 static void srch_set_a_button P_((Widget pbw, int whether));
 static void srch_use_cb P_((Widget w, XtPointer client, XtPointer call));
@@ -67,9 +67,9 @@ static void srch_acc_ok_cb P_((Widget w, XtPointer client, XtPointer call));
 static void srch_acc_cb P_((Widget wid, XtPointer client, XtPointer call));
 static void srch_goal_cb P_((Widget w, XtPointer client, XtPointer call));
 static void srch_on_off_cb P_((Widget w, XtPointer client, XtPointer call));
-static srch_minmax P_((double Mjd, double v, double *tmincp));
-static srch_solve0 P_((double Mjd, double v, double *tmincp));
-static srch_binary P_((double Mjd, double v, double *tmincp));
+static int srch_minmax P_((double Mjd, double v, double *tmincp));
+static int srch_solve0 P_((double Mjd, double v, double *tmincp));
+static int srch_binary P_((double Mjd, double v, double *tmincp));
 
 
 /* the widgets we need direct access to */
@@ -1076,3 +1076,6 @@ double *tmincp;
 	    return (0);
 	}
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: srchmenu.c,v $ $Date: 1998/07/12 02:33:52 $ $Revision: 1.2 $ $Name:  $"};
