@@ -2,7 +2,8 @@
  * fill in the sky position (s_*) portions.
  * calculation of positional coordinates reworked by
  * Michael Sternberg <sternberg@physik.tu-chemnitz.de>
- * 3/11/98: deflect was using op->s_hlong before being set in cir_pos().
+ *  3/11/98: deflect was using op->s_hlong before being set in cir_pos().
+ *  4/19/98: just edit a comment
  */
 
 #include <stdio.h>
@@ -92,7 +93,7 @@ Obj *op;
 	/* compute magnitude and angular size */
 	f = op->s_phase ? 5*log10(rp*rho) - 5*log10(op->s_phase/100) : 100;
 	set_smag (op, mag+f);
-	op->s_size = dia/rho + 0.5;
+	op->s_size = dia/rho;
 
 	return (0);
 }
@@ -123,7 +124,7 @@ Obj *op;
 	    op->f_dec = tdec;
 	}
 
-	/* set ra/dec to their values at epoch of date */
+	/* set ra/dec to astrometric @ epoch of date */
 	ra = op->f_RA;
 	dec = op->f_dec;
 	precess (op->f_epoch, mjd, &ra, &dec);
@@ -732,3 +733,6 @@ double *ra, *dec;	/* geocentric equatoreal */
 	/* back to spherical */
 	cartsph(u[0], u[1], u[2], ra, dec, &rho);	/* rho thrown away */
 }
+
+/* For RCS Only -- Do Not Edit */
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: circum.c,v $ $Date: 1999/02/15 21:42:18 $ $Revision: 1.2 $ $Name:  $"};
